@@ -52,8 +52,8 @@ KCMAkregatorArchiveConfig::KCMAkregatorArchiveConfig( QWidget* parent, const QVa
     connect( m_ui.rb_LimitArticleAge, SIGNAL(toggled(bool)),
              m_ui.kcfg_MaxArticleAge, SLOT(setEnabled(bool)) );
 
-    m_ui.kcfg_MaxArticleNumber->setSuffix(ki18np(" article", " articles"));
-    m_ui.kcfg_MaxArticleAge->setSuffix(ki18np(" day", " days"));
+    m_ui.kcfg_MaxArticleNumber->setSuffix(ki18ncp("Limit feed archive size to:", " article", " articles"));
+    m_ui.kcfg_MaxArticleAge->setSuffix(ki18ncp("Delete articles older than:", " day", " days"));
     m_archiveModeGroup = new QButtonGroup( this );
     m_archiveModeGroup->addButton( m_ui.rb_KeepAllArticles, Settings::EnumArchiveMode::keepAllArticles );
     m_archiveModeGroup->addButton( m_ui.rb_LimitArticleNumber, Settings::EnumArchiveMode::limitArticleNumber );
