@@ -1,7 +1,7 @@
 /*
  *  kalarmapp.h  -  the KAlarm application object
  *  Program:  kalarm
- *  Copyright © 2001-2010 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2011 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -94,6 +94,9 @@ class KAlarmApp : public KUniqueApplication
     public slots:
         void               processQueue();
         void               setAlarmsEnabled(bool);
+#ifdef USE_AKONADI
+        void               atLoginEventAdded(const KAEvent&);
+#endif
         void               stopAudio();
         void               spreadWindows(bool);
         void               emailSent(KAMail::JobData&, const QStringList& errmsgs, bool copyerr = false);
