@@ -23,12 +23,6 @@
 
 #include "alarmcalendar.h"
 #include "alarmlistview.h"
-#ifdef USE_AKONADI
-#include "akonadimodel.h"
-#include "collectionmodel.h"
-#else
-#include "alarmresources.h"
-#endif
 #include "alarmtext.h"
 #include "functions.h"
 #include "kalarmapp.h"
@@ -103,10 +97,7 @@ TrayWindow::TrayWindow(MainWindow* parent)
     actions->addAction(QLatin1String("tNew"), mActionNew);
     contextMenu()->addAction(mActionNew);
     connect(mActionNew, SIGNAL(selected(EditAlarmDlg::Type)), SLOT(slotNewAlarm(EditAlarmDlg::Type)));
-
-    mActionNewFromTemplate = KAlarm::createNewFromTemplateAction(i18nc("@action", "New Alarm From &Template"), actions, QLatin1String("tNewFromTempl"));
-    contextMenu()->addAction(mActionNewFromTemplate);
-    connect(mActionNewFromTemplate, SIGNAL(selected(const KAEvent*)), SLOT(slotNewFromTemplate(const KAEvent*)));
+    connect(mActionNew->fromTemplateAlarmAction(), SIGNAL(selected(const KAEvent*)), SLOT(slotNewFromTemplate(const KAEvent*)));
     contextMenu()->addSeparator();
 
     KAction* a = KAlarm::createStopPlayAction(this);
@@ -131,15 +122,9 @@ TrayWindow::TrayWindow(MainWindow* parent)
     // Set icon to correspond with the alarms enabled menu status
     setEnabledStatus(theApp()->alarmsEnabled());
 
-#ifdef USE_AKONADI
-    connect(AkonadiModel::instance(), SIGNAL(collectionStatusChanged(const Akonadi::Collection&, AkonadiModel::Change, const QVariant&)), SLOT(slotCalendarStatusChanged()));
-#else
-    connect(AlarmResources::instance(), SIGNAL(resourceStatusChanged(AlarmResource*, AlarmResources::Change)), SLOT(slotCalendarStatusChanged()));
-#endif
     connect(AlarmCalendar::resources(), SIGNAL(haveDisabledAlarmsChanged(bool)), SLOT(slotHaveDisabledAlarms(bool)));
     connect(this, SIGNAL(activateRequested(bool, const QPoint&)), SLOT(slotActivateRequested()));
     connect(this, SIGNAL(secondaryActivateRequested(const QPoint&)), SLOT(slotSecondaryActivateRequested()));
-    slotCalendarStatusChanged();   // initialise action states
     slotHaveDisabledAlarms(AlarmCalendar::resources()->haveDisabledAlarms());
 
     // Hack: KSNI does not let us know when it is about to show the tooltip,
@@ -190,23 +175,6 @@ TrayWindow::~TrayWindow()
     emit deleted();
 }
 
-/******************************************************************************
-* Called when the status of a calendar has changed.
-* Enable or disable actions appropriately.
-*/
-void TrayWindow::slotCalendarStatusChanged()
-{
-    // Find whether there are any writable active alarm calendars
-#ifdef USE_AKONADI
-    bool active = !CollectionControlModel::enabledCollections(KAlarm::CalEvent::ACTIVE, true).isEmpty();
-    mActionNewFromTemplate->setEnabled(active && TemplateListModel::all()->haveEvents());
-#else
-    bool active = AlarmResources::instance()->activeCount(KAlarm::CalEvent::ACTIVE, true);
-    mActionNewFromTemplate->setEnabled(active && EventListModel::templates()->haveEvents());
-#endif
-    mActionNew->setEnabled(active);
-}
-
 /******************************************************************************
 *  Called when the "New Alarm" menu item is selected to edit a new alarm.
 */
