@@ -38,6 +38,7 @@
 #include <qwindowdefs.h> // for WId
 
 #include <utils/pimpl_ptr.h>
+#include <utils/types.h> // for ExecutionContext
 
 #include <vector>
 
@@ -54,7 +55,7 @@ namespace Kleo {
     class KeyListController;
     class AbstractKeyListSortFilterProxyModel;
 
-    class Command : public QObject {
+    class Command : public QObject, public ExecutionContext {
         Q_OBJECT
     public:
         explicit Command( KeyListController * parent );
@@ -75,6 +76,13 @@ namespace Kleo {
             // esoteric:
             MayOnlyBeSecretKeyIfOwnerTrustIsNotYetUltimate = 64, // for set-owner-trust
 
+            AnyCardHasNullPin   = 128,
+            AnyCardCanLearnKeys = 256,
+
+            MustBeRoot          = 512,
+            MustBeTrustedRoot   = 1024|MustBeRoot,
+            MustBeUntrustedRoot = 2048|MustBeRoot,
+
             _AllRestrictions_Helper,
             AllRestrictions = 2*(_AllRestrictions_Helper-1) - 1
         };
@@ -111,6 +119,9 @@ namespace Kleo {
         virtual void doStart() = 0;
         virtual void doCancel() = 0;
 
+    private:
+        /* reimp */ void applyWindowID( QWidget * wid ) const;
+
     protected:
         void addTemporaryView( const QString & title, AbstractKeyListSortFilterProxyModel * proxy=0, const QString & tabToolTip=QString() );
 
