@@ -37,15 +37,21 @@
 #include <utils/input.h>
 #include <utils/output.h>
 #include <utils/classify.h>
-#include <utils/stl_util.h>
 #include <utils/kleo_assert.h>
 
+#include <kleo/stl_util.h>
 #include <kleo/checksumdefinition.h>
 
 #include <KLocale>
 #include <kdebug.h>
 #include <KSaveFile>
 
+#include <QLayout>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QLabel>
+#include <QListWidget>
+
 #include <QPointer>
 #include <QFileInfo>
 #include <QThread>
@@ -60,12 +66,72 @@
 #include <gpg-error.h>
 
 #include <deque>
+#include <map>
 #include <limits>
 
 using namespace Kleo;
 using namespace Kleo::Crypto;
 using namespace boost;
 
+namespace {
+
+    class ResultDialog : public QDialog {
+        Q_OBJECT
+    public:
+        ResultDialog( const QStringList & created, const QStringList & errors, QWidget * parent=0, Qt::WindowFlags f=0 )
+            : QDialog( parent, f ),
+              createdLB( created.empty()
+                         ? i18nc("@info","No checksum files have been created.")
+                         : i18nc("@info","These checksum files have been successfully created:"), this ),
+              createdLW( this ),
+              errorsLB( errors.empty()
+                        ? i18nc("@info","There were no errors.")
+                        : i18nc("@info","The following errors were encountered:"), this ),
+              errorsLW( this ),
+              buttonBox( QDialogButtonBox::Ok, Qt::Horizontal, this ),
+              vlay( this )
+        {
+            KDAB_SET_OBJECT_NAME( createdLB );
+            KDAB_SET_OBJECT_NAME( createdLW );
+            KDAB_SET_OBJECT_NAME( errorsLB );
+            KDAB_SET_OBJECT_NAME( errorsLW );
+            KDAB_SET_OBJECT_NAME( buttonBox );
+            KDAB_SET_OBJECT_NAME( vlay );
+
+            createdLW.addItems( created );
+            QRect r;
+            for( int i = 0; i < created.size(); ++i )
+                r = r.united( createdLW.visualRect( createdLW.model()->index( 0, i ) ) );
+            createdLW.setMinimumWidth( qMin( 1024, r.width() + 4 * createdLW.frameWidth() ) );
+
+            errorsLW.addItems( errors );
+
+            vlay.addWidget( &createdLB );
+            vlay.addWidget( &createdLW, 1 );
+            vlay.addWidget( &errorsLB );
+            vlay.addWidget( &errorsLW, 1 );
+            vlay.addWidget( &buttonBox );
+
+            if ( created.empty() )
+                createdLW.hide();
+            if ( errors.empty() )
+                errorsLW.hide();
+
+            connect( &buttonBox, SIGNAL(accepted()), this, SLOT(accept()) );
+            connect( &buttonBox, SIGNAL(rejected()), this, SLOT(reject()) );
+        }
+
+    private:
+        QLabel createdLB;
+        QListWidget createdLW;
+        QLabel errorsLB;
+        QListWidget errorsLW;
+        QDialogButtonBox buttonBox;
+        QVBoxLayout vlay;
+    };
+
+}
+
 #ifdef Q_OS_UNIX
 static const bool HAVE_UNIX = true;
 #else
@@ -76,7 +142,7 @@ static const Qt::CaseSensitivity fs_cs = HAVE_UNIX ? Qt::CaseSensitive : Qt::Cas
 
 static QStringList fs_sort( QStringList l ) {
     int (*QString_compare)(const QString&,const QString&,Qt::CaseSensitivity) = &QString::compare;
-    kdtools::sort( l, bind( QString_compare, _1, _2, fs_cs ) < 0 );
+    kdtools::sort( l, boost::bind( QString_compare, _1, _2, fs_cs ) < 0 );
     return l;
 }
 
@@ -88,7 +154,7 @@ static QStringList fs_intersect( QStringList l1, QStringList l2 ) {
     std::set_intersection( l1.begin(), l1.end(),
                            l2.begin(), l2.end(),
                            std::back_inserter( result ),
-                           bind( QString_compare, _1, _2, fs_cs ) < 0 );
+                           boost::bind( QString_compare, _1, _2, fs_cs ) < 0 );
     return result;
 }
 
@@ -107,7 +173,7 @@ namespace {
         const QList<QRegExp> m_regexps;
         explicit matches_any( const QList<QRegExp> & regexps ) : m_regexps( regexps ) {}
         bool operator()( const QString & s ) const {
-            return kdtools::any( m_regexps, bind( &QRegExp::exactMatch, _1, s ) );
+            return kdtools::any( m_regexps, boost::bind( &QRegExp::exactMatch, _1, s ) );
         }
     };
 }
@@ -125,10 +191,14 @@ Q_SIGNALS:
 
 private:
     void slotOperationFinished() {
+#ifndef QT_NO_PROGRESSDIALOG
         if ( progressDialog ) {
             progressDialog->setValue( progressDialog->maximum() );
             progressDialog->close();
         }
+#endif // QT_NO_PROGRESSDIALOG
+        ResultDialog * const dlg = new ResultDialog( created, errors );
+        q->bringToForeground( dlg );
         if ( !errors.empty() )
             q->setLastError( gpg_error( GPG_ERR_GENERAL ),
                              errors.join( "\n" ) );
@@ -136,35 +206,42 @@ private:
     }
     void slotProgress( int current, int total, const QString & what ) {
         qDebug( "progress: %d/%d: %s", current, total, qPrintable( what ) );
+#ifndef QT_NO_PROGRESSDIALOG
         if ( !progressDialog )
             return;
         progressDialog->setMaximum( total );
         progressDialog->setValue( current );
         progressDialog->setLabelText( what );
+#endif // QT_NO_PROGRESSDIALOG
     }
 
 private:
     /* reimp */ void run();
 
 private:
+#ifndef QT_NO_PROGRESSDIALOG
     QPointer<QProgressDialog> progressDialog;
+#endif
     mutable QMutex mutex;
     const std::vector< shared_ptr<ChecksumDefinition> > checksumDefinitions;
     shared_ptr<ChecksumDefinition> checksumDefinition;
     QStringList files;
-    QStringList errors;
+    QStringList errors, created;
     bool allowAddition;
     volatile bool canceled;
 };
 
 CreateChecksumsController::Private::Private( CreateChecksumsController * qq )
     : q( qq ),
+#ifndef QT_NO_PROGRESSDIALOG
       progressDialog(),
+#endif
       mutex(),
       checksumDefinitions( ChecksumDefinition::getChecksumDefinitions() ),
       checksumDefinition( ChecksumDefinition::getDefaultChecksumDefinition( checksumDefinitions ) ),
       files(),
       errors(),
+      created(),
       allowAddition( false ),
       canceled( false )
 {
@@ -221,14 +298,18 @@ void CreateChecksumsController::start() {
     {
         const QMutexLocker locker( &d->mutex );
 
+#ifndef QT_NO_PROGRESSDIALOG
         d->progressDialog = new QProgressDialog( i18n("Initializing..."), i18n("Cancel"), 0, 0 );
+        applyWindowID( d->progressDialog );
         d->progressDialog->setAttribute( Qt::WA_DeleteOnClose );
         d->progressDialog->setMinimumDuration( 1000 );
         d->progressDialog->setWindowTitle( i18nc("@title:window","Create Checksum Progress") );
         connect( d->progressDialog, SIGNAL(canceled()), this, SLOT(cancel()) );
+#endif // QT_NO_PROGRESSDIALOG
 
         d->canceled = false;
         d->errors.clear();
+        d->created.clear();
     }
 
     d->start();
@@ -257,7 +338,7 @@ static QStringList remove_checksum_files( QStringList l, const QList<QRegExp> &
     QStringList::iterator end = l.end();
     Q_FOREACH( const QRegExp & rx, rxs )
         end = std::remove_if( l.begin(), end,
-                              bind( &QRegExp::exactMatch, rx, _1 ) );
+                              boost::bind( &QRegExp::exactMatch, rx, _1 ) );
     l.erase( end, l.end() );
     return l;
 }
@@ -412,7 +493,7 @@ static std::vector<Dir> find_dirs_by_input_files( const QStringList & files, con
             dirs2files[ dir ] = remove_checksum_files( dir.entryList( QDir::Files ), patterns );
             kdtools::transform( dir.entryList( QDir::Dirs|QDir::NoDotAndDotDot ),
                                 std::inserter( inputs, inputs.begin() ),
-                                bind( &QDir::absoluteFilePath, cref(dir), _1 ) );
+                                boost::bind( &QDir::absoluteFilePath, cref(dir), _1 ) );
         } else {
             dirs2files[fi.dir()].push_back( file );
         }
@@ -458,9 +539,7 @@ static QString process( const Dir & dir, bool * fatal ) {
     p.setWorkingDirectory( dir.dir.absolutePath() );
     p.setStandardOutputFile( dir.dir.absoluteFilePath( file.QFile::fileName() /*!sic*/ ) );
     const QString program = dir.checksumDefinition->createCommand();
-    const QStringList arguments = dir.checksumDefinition->createCommandArguments( dir.inputFiles );
-    qDebug( "[%p] Starting %s %s", &p, qPrintable( program ), qPrintable( arguments.join(" ") ) );
-    p.start( program, arguments );
+    dir.checksumDefinition->startCreateCommand( &p, dir.inputFiles );
     p.waitForFinished();
     qDebug( "[%p] Exit code %d.", &p, p.exitCode() );
 
@@ -500,6 +579,7 @@ void CreateChecksumsController::Private::run() {
     locker.unlock();
 
     QStringList errors;
+    QStringList created;
 
     if ( !checksumDefinition ) {
         errors.push_back( i18n("No checksum programs defined.") );
@@ -519,7 +599,7 @@ void CreateChecksumsController::Private::run() {
 
     const bool haveSumFiles
         = kdtools::all( files, matches_any( get_patterns( checksumDefinitions ) ) );
-    const function<void(int)> progressCb = bind( &Private::progress, this, _1, 0, scanning );
+    const function<void(int)> progressCb = boost::bind( &Private::progress, this, _1, 0, scanning );
     const std::vector<Dir> dirs = haveSumFiles
         ? find_dirs_by_sum_files( files, allowAddition, progressCb, checksumDefinitions )
         : find_dirs_by_input_files( files, checksumDefinition, allowAddition, progressCb, checksumDefinitions ) ;
@@ -551,6 +631,8 @@ void CreateChecksumsController::Private::run() {
                 const QString error = process( dir, &fatal );
                 if ( !error.isEmpty() )
                     errors.push_back( error );
+                else
+                    created.push_back( dir.dir.absoluteFilePath( dir.sumFile ) );
                 done += dir.totalSize;
                 if ( fatal || canceled )
                     break;
@@ -563,6 +645,7 @@ void CreateChecksumsController::Private::run() {
     locker.relock();
 
     this->errors = errors;
+    this->created = created;
 
     // mutex unlocked by QMutexLocker
 
