@@ -29,16 +29,23 @@
 
 
 #include "antispamwizard.h"
-#include "kcursorsaver.h"
-#include "accountmanager.h"
-#include "kmfilter.h"
-#include "kmfilteraction.h"
-#include "kmfiltermgr.h"
+#include "messageviewer/kcursorsaver.h"
 #include "kmkernel.h"
-#include "folderselectiontreewidget.h"
 #include "kmmainwin.h"
-#include "networkaccount.h"
 #include "folderrequester.h"
+#include "foldertreewidget.h"
+#include "foldertreeview.h"
+#include "readablecollectionproxymodel.h"
+#include "util.h"
+#include "pop3settings.h"
+#include "mailcommon/mailutil.h"
+#include "mailcommon/imapsettings.h"
+#include "mailcommon/mailkernel.h"
+#include "mailcommon/mailfilter.h"
+#include "mailcommon/filteraction.h"
+#include "mailcommon/filtermanager.h"
+
+#include <Akonadi/AgentInstance>
 
 #include <kaction.h>
 #include <kdebug.h>
@@ -53,18 +60,17 @@
 #include <QApplication>
 #include <qdom.h>
 #include <QLabel>
-#include <QLayout>
 #include <QTimer>
-#include <QPixmap>
 #include <QGridLayout>
 #include <QHBoxLayout>
 #include <QBoxLayout>
 #include <QVBoxLayout>
 
 using namespace KMail;
+using namespace MailCommon;
 
 AntiSpamWizard::AntiSpamWizard( WizardMode mode,
-                                QWidget* parent, MainFolderView * mainFolderTree )
+                                QWidget* parent )
   : KAssistantDialog( parent ),
     mInfoPage( 0 ),
     mSpamRulesPage( 0 ),
@@ -82,32 +88,31 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
     kDebug() << endl <<"Considered anti-spam tools:";
   else
     kDebug() << endl <<"Considered anti-virus tools:";
-#endif
+
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
         it != mToolList.end(); ++it ) {
-#ifndef NDEBUG
-    kDebug() <<"Predefined tool:" << (*it).getId();
-    kDebug() <<"Config version:" << (*it).getVersion();
-    kDebug() <<"Selection priority:" << (*it).getPrio();
-    kDebug() <<"Displayed name:" << (*it).getVisibleName();
-    kDebug() <<"Executable:" << (*it).getExecutable();
-    kDebug() <<"WhatsThis URL:" << (*it).getWhatsThisText();
-    kDebug() <<"Filter name:" << (*it).getFilterName();
-    kDebug() <<"Detection command:" << (*it).getDetectCmd();
-    kDebug() <<"Learn spam command:" << (*it).getSpamCmd();
-    kDebug() <<"Learn ham command:" << (*it).getHamCmd();
-    kDebug() <<"Detection header:" << (*it).getDetectionHeader();
-    kDebug() <<"Detection pattern:" << (*it).getDetectionPattern();
-    kDebug() <<"Use as RegExp:" << (*it).isUseRegExp();
-    kDebug() <<"Supports Bayes Filter:" << (*it).useBayesFilter();
-    kDebug() <<"Type:" << (*it).getType();
-#endif
+    kDebug() << "Predefined tool:" << (*it).getId();
+    kDebug() << "Config version:" << (*it).getVersion();
+    kDebug() << "Selection priority:" << (*it).getPrio();
+    kDebug() << "Displayed name:" << (*it).getVisibleName();
+    kDebug() << "Executable:" << (*it).getExecutable();
+    kDebug() << "WhatsThis URL:" << (*it).getWhatsThisText();
+    kDebug() << "Filter name:" << (*it).getFilterName();
+    kDebug() << "Detection command:" << (*it).getDetectCmd();
+    kDebug() << "Learn spam command:" << (*it).getSpamCmd();
+    kDebug() << "Learn ham command:" << (*it).getHamCmd();
+    kDebug() << "Detection header:" << (*it).getDetectionHeader();
+    kDebug() << "Detection pattern:" << (*it).getDetectionPattern();
+    kDebug() << "Use as RegExp:" << (*it).isUseRegExp();
+    kDebug() << "Supports Bayes Filter:" << (*it).useBayesFilter();
+    kDebug() << "Type:" << (*it).getType();
   }
+#endif
 
   setWindowTitle( ( mMode == AntiSpam ) ? i18n( "Anti-Spam Wizard" )
                                     : i18n( "Anti-Virus Wizard" ) );
   mInfoPage = new ASWizInfoPage( mMode, 0, "" );
-  addPage( mInfoPage,
+  mInfoPageItem = addPage( mInfoPage,
            ( mMode == AntiSpam )
            ? i18n( "Welcome to the KMail Anti-Spam Wizard" )
            : i18n( "Welcome to the KMail Anti-Virus Wizard" ) );
@@ -115,14 +120,14 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
             this, SLOT( checkProgramsSelections( void ) ) );
 
   if ( mMode == AntiSpam ) {
-    mSpamRulesPage = new ASWizSpamRulesPage( 0, "", mainFolderTree );
-    addPage( mSpamRulesPage, i18n( "Options to fine-tune the handling of spam messages" ));
+    mSpamRulesPage = new ASWizSpamRulesPage( 0, "" );
+    mSpamRulesPageItem = addPage( mSpamRulesPage, i18n( "Options to fine-tune the handling of spam messages" ));
     connect( mSpamRulesPage, SIGNAL( selectionChanged( void ) ),
              this, SLOT( slotBuildSummary( void ) ) );
   }
   else {
-    mVirusRulesPage = new ASWizVirusRulesPage( 0, "", mainFolderTree );
-    addPage( mVirusRulesPage, i18n( "Options to fine-tune the handling of virus messages" ));
+    mVirusRulesPage = new ASWizVirusRulesPage( 0, "" );
+    mVirusRulesPageItem = addPage( mVirusRulesPage, i18n( "Options to fine-tune the handling of virus messages" ));
     connect( mVirusRulesPage, SIGNAL( selectionChanged( void ) ),
              this, SLOT( checkVirusRulesSelections( void ) ) );
   }
@@ -132,7 +137,7 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
 
   if ( mMode == AntiSpam ) {
     mSummaryPage = new ASWizSummaryPage( 0, "" );
-    addPage( mSummaryPage, i18n( "Summary of changes to be made by this wizard" ) );
+    mSummaryPageItem = addPage( mSummaryPage, i18n( "Summary of changes to be made by this wizard" ) );
   }
 
   QTimer::singleShot( 0, this, SLOT( checkToolAvailability( void ) ) );
@@ -142,39 +147,44 @@ AntiSpamWizard::AntiSpamWizard( WizardMode mode,
 void AntiSpamWizard::accept()
 {
   if ( mSpamRulesPage ) {
-    kDebug() <<"Folder name for messages classified as spam is"
-                    << mSpamRulesPage->selectedSpamFolderName();
-    kDebug() <<"Folder name for messages classified as unsure is"
-                    << mSpamRulesPage->selectedUnsureFolderName();
+    kDebug() << "Folder name for messages classified as spam is"
+                    << mSpamRulesPage->selectedSpamCollectionId();
+    kDebug() << "Folder name for messages classified as unsure is"
+                    << mSpamRulesPage->selectedUnsureCollectionId();
+  }
+  if ( mVirusRulesPage ) {
+    kDebug() << "Folder name for viruses is"
+             << mVirusRulesPage->selectedFolderName();
   }
-  if ( mVirusRulesPage )
-    kDebug() <<"Folder name for viruses is"
-                    << mVirusRulesPage->selectedFolderName();
 
-  KMFilterActionDict dict;
-  QList<KMFilter*> filterList;
+  FilterActionDict dict;
+  QList<MailFilter*> filterList;
   bool replaceExistingFilters = false;
 
   // Let's start with virus detection and handling,
   // so we can avoid spam checks for viral messages
   if ( mMode == AntiVirus ) {
-    for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
-          it != mToolList.end(); ++it ) {
+    if ( !mVirusToolsUsed ) {
+      KDialog::accept();
+      return;
+    }
+    for ( QList<SpamToolConfig>::const_iterator it = mToolList.constBegin();
+          it != mToolList.constEnd(); ++it ) {
       if ( mInfoPage->isProgramSelected( (*it).getVisibleName() ) &&
          ( mVirusRulesPage->pipeRulesSelected() && (*it).isVirusTool() ) )
       {
         // pipe messages through the anti-virus tools,
         // one single filter for each tool
         // (could get combined but so it's easier to understand for the user)
-        KMFilter* pipeFilter = new KMFilter();
-        QList<KMFilterAction*> *pipeFilterActions = pipeFilter->actions();
-        KMFilterAction* pipeFilterAction = dict.value( "filter app" )->create();
+        MailFilter* pipeFilter = new MailFilter();
+        QList<FilterAction*> *pipeFilterActions = pipeFilter->actions();
+        FilterAction* pipeFilterAction = dict.value( "filter app" )->create();
         pipeFilterAction->argsFromString( (*it).getDetectCmd() );
         pipeFilterActions->append( pipeFilterAction );
-        KMSearchPattern* pipeFilterPattern = pipeFilter->pattern();
+        SearchPattern* pipeFilterPattern = pipeFilter->pattern();
         pipeFilterPattern->setName( uniqueNameFor( (*it).getFilterName() ) );
-        pipeFilterPattern->append( KMSearchRule::createInstance( "<size>",
-                                   KMSearchRule::FuncIsGreaterOrEqual, "0" ) );
+        pipeFilterPattern->append( SearchRule::createInstance( "<size>",
+                                   SearchRule::FuncIsGreaterOrEqual, "0" ) );
         pipeFilter->setApplyOnOutbound( false);
         pipeFilter->setApplyOnInbound();
         pipeFilter->setApplyOnExplicit();
@@ -188,19 +198,19 @@ void AntiSpamWizard::accept()
     if ( mVirusRulesPage->moveRulesSelected() )
     {
       // Sort out viruses depending on header fields set by the tools
-      KMFilter* virusFilter = new KMFilter();
-      QList<KMFilterAction*> *virusFilterActions = virusFilter->actions();
-      KMFilterAction* virusFilterAction1 = dict.value( "transfer" )->create();
+      MailFilter* virusFilter = new MailFilter();
+      QList<FilterAction*> *virusFilterActions = virusFilter->actions();
+      FilterAction* virusFilterAction1 = dict.value( "transfer" )->create();
       virusFilterAction1->argsFromString( mVirusRulesPage->selectedFolderName() );
       virusFilterActions->append( virusFilterAction1 );
       if ( mVirusRulesPage->markReadRulesSelected() ) {
-        KMFilterAction* virusFilterAction2 = dict.value( "set status" )->create();
+        FilterAction* virusFilterAction2 = dict.value( "set status" )->create();
         virusFilterAction2->argsFromString( "R" ); // Read
         virusFilterActions->append( virusFilterAction2 );
       }
-      KMSearchPattern* virusFilterPattern = virusFilter->pattern();
+      SearchPattern* virusFilterPattern = virusFilter->pattern();
       virusFilterPattern->setName( uniqueNameFor( i18n( "Virus handling" ) ) );
-      virusFilterPattern->setOp( KMSearchPattern::OpOr );
+      virusFilterPattern->setOp( SearchPattern::OpOr );
       for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
             it != mToolList.end(); ++it ) {
         if ( mInfoPage->isProgramSelected( (*it).getVisibleName() ))
@@ -211,12 +221,12 @@ void AntiSpamWizard::accept()
               const QString & pattern = (*it).getDetectionPattern();
               if ( (*it).isUseRegExp() )
                 virusFilterPattern->append(
-                  KMSearchRule::createInstance( header,
-                  KMSearchRule::FuncRegExp, pattern ) );
+                  SearchRule::createInstance( header,
+                  SearchRule::FuncRegExp, pattern ) );
               else
                 virusFilterPattern->append(
-                  KMSearchRule::createInstance( header,
-                  KMSearchRule::FuncContains, pattern ) );
+                  SearchRule::createInstance( header,
+                  SearchRule::FuncContains, pattern ) );
           }
         }
       }
@@ -230,6 +240,10 @@ void AntiSpamWizard::accept()
     }
   }
   else { // AntiSpam mode
+    if ( !mSpamToolsUsed ) {
+      KDialog::accept();
+      return;
+    }
     // TODO Existing filters with same name are replaced. This is hardcoded
     // ATM and needs to be replaced with a value from a (still missing)
     // checkbox in the GUI. At least, the replacement is announced in the GUI.
@@ -242,18 +256,18 @@ void AntiSpamWizard::accept()
         // pipe messages through the anti-spam tools,
         // one single filter for each tool
         // (could get combined but so it's easier to understand for the user)
-        KMFilter* pipeFilter = new KMFilter();
-        QList<KMFilterAction*> *pipeFilterActions = pipeFilter->actions();
-        KMFilterAction* pipeFilterAction = dict.value( "filter app" )->create();
+        MailFilter* pipeFilter = new MailFilter();
+        QList<FilterAction*> *pipeFilterActions = pipeFilter->actions();
+        FilterAction* pipeFilterAction = dict.value( "filter app" )->create();
         pipeFilterAction->argsFromString( (*it).getDetectCmd() );
         pipeFilterActions->append( pipeFilterAction );
-        KMSearchPattern* pipeFilterPattern = pipeFilter->pattern();
+        SearchPattern* pipeFilterPattern = pipeFilter->pattern();
         if ( replaceExistingFilters )
           pipeFilterPattern->setName( (*it).getFilterName() );
         else
           pipeFilterPattern->setName( uniqueNameFor( (*it).getFilterName() ) );
-        pipeFilterPattern->append( KMSearchRule::createInstance( "<size>",
-                                   KMSearchRule::FuncIsLessOrEqual, "256000" ) );
+        pipeFilterPattern->append( SearchRule::createInstance( "<size>",
+                                   SearchRule::FuncIsLessOrEqual, "256000" ) );
         pipeFilter->setApplyOnOutbound( false);
         pipeFilter->setApplyOnInbound();
         pipeFilter->setApplyOnExplicit();
@@ -265,28 +279,28 @@ void AntiSpamWizard::accept()
     }
 
     // Sort out spam depending on header fields set by the tools
-    KMFilter* spamFilter = new KMFilter();
-    QList<KMFilterAction*> *spamFilterActions = spamFilter->actions();
+    MailFilter* spamFilter = new MailFilter();
+    QList<FilterAction*> *spamFilterActions = spamFilter->actions();
     if ( mSpamRulesPage->moveSpamSelected() )
     {
-      KMFilterAction* spamFilterAction1 = dict.value( "transfer" )->create();
-      spamFilterAction1->argsFromString( mSpamRulesPage->selectedSpamFolderName() );
+      FilterAction* spamFilterAction1 = dict.value( "transfer" )->create();
+      spamFilterAction1->argsFromString( mSpamRulesPage->selectedSpamCollectionId() );
       spamFilterActions->append( spamFilterAction1 );
     }
-    KMFilterAction* spamFilterAction2 = dict.value( "set status" )->create();
+    FilterAction* spamFilterAction2 = dict.value( "set status" )->create();
     spamFilterAction2->argsFromString( "P" ); // Spam
     spamFilterActions->append( spamFilterAction2 );
     if ( mSpamRulesPage->markAsReadSelected() ) {
-      KMFilterAction* spamFilterAction3 = dict.value( "set status" )->create();
+      FilterAction* spamFilterAction3 = dict.value( "set status" )->create();
       spamFilterAction3->argsFromString( "R" ); // Read
       spamFilterActions->append( spamFilterAction3 );
     }
-    KMSearchPattern* spamFilterPattern = spamFilter->pattern();
+    SearchPattern* spamFilterPattern = spamFilter->pattern();
     if ( replaceExistingFilters )
       spamFilterPattern->setName( i18n( "Spam Handling" ) );
     else
       spamFilterPattern->setName( uniqueNameFor( i18n( "Spam Handling" ) ) );
-    spamFilterPattern->setOp( KMSearchPattern::OpOr );
+    spamFilterPattern->setOp( SearchPattern::OpOr );
     for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
           it != mToolList.end(); ++it ) {
       if ( mInfoPage->isProgramSelected( (*it).getVisibleName() ) )
@@ -297,12 +311,12 @@ void AntiSpamWizard::accept()
             const QString & pattern = (*it).getDetectionPattern();
             if ( (*it).isUseRegExp() )
               spamFilterPattern->append(
-                KMSearchRule::createInstance( header,
-                KMSearchRule::FuncRegExp, pattern ) );
+                SearchRule::createInstance( header,
+                SearchRule::FuncRegExp, pattern ) );
             else
               spamFilterPattern->append(
-                KMSearchRule::createInstance( header,
-                KMSearchRule::FuncContains, pattern ) );
+                SearchRule::createInstance( header,
+                SearchRule::FuncContains, pattern ) );
           }
       }
     }
@@ -317,17 +331,17 @@ void AntiSpamWizard::accept()
     {
       // Sort out messages classified as unsure
       bool atLeastOneUnsurePattern = false;
-      KMFilter* unsureFilter = new KMFilter();
-      QList<KMFilterAction*> *unsureFilterActions = unsureFilter->actions();
-      KMFilterAction* unsureFilterAction1 = dict.value( "transfer" )->create();
-      unsureFilterAction1->argsFromString( mSpamRulesPage->selectedUnsureFolderName() );
+      MailFilter* unsureFilter = new MailFilter();
+      QList<FilterAction*> *unsureFilterActions = unsureFilter->actions();
+      FilterAction* unsureFilterAction1 = dict.value( "transfer" )->create();
+      unsureFilterAction1->argsFromString( mSpamRulesPage->selectedUnsureCollectionId() );
       unsureFilterActions->append( unsureFilterAction1 );
-      KMSearchPattern* unsureFilterPattern = unsureFilter->pattern();
+      SearchPattern* unsureFilterPattern = unsureFilter->pattern();
       if ( replaceExistingFilters )
         unsureFilterPattern->setName( i18n( "Semi spam (unsure) handling" ) );
       else
         unsureFilterPattern->setName( uniqueNameFor( i18n( "Semi spam (unsure) handling" ) ) );
-      unsureFilterPattern->setOp( KMSearchPattern::OpOr );
+      unsureFilterPattern->setOp( SearchPattern::OpOr );
       for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
             it != mToolList.end(); ++it ) {
         if ( mInfoPage->isProgramSelected( (*it).getVisibleName() ) )
@@ -339,12 +353,12 @@ void AntiSpamWizard::accept()
               const QString & pattern = (*it).getDetectionPattern2();
               if ( (*it).isUseRegExp() )
                 unsureFilterPattern->append(
-                  KMSearchRule::createInstance( header,
-                  KMSearchRule::FuncRegExp, pattern ) );
+                  SearchRule::createInstance( header,
+                  SearchRule::FuncRegExp, pattern ) );
               else
                 unsureFilterPattern->append(
-                  KMSearchRule::createInstance( header,
-                  KMSearchRule::FuncContains, pattern ) );
+                  SearchRule::createInstance( header,
+                  SearchRule::FuncContains, pattern ) );
             }
         }
       }
@@ -361,10 +375,10 @@ void AntiSpamWizard::accept()
     }
 
     // Classify messages manually as Spam
-    KMFilter* classSpamFilter = new KMFilter();
+    MailFilter* classSpamFilter = new MailFilter();
     classSpamFilter->setIcon( "mail-mark-junk" );
-    QList<KMFilterAction*> *classSpamFilterActions = classSpamFilter->actions();
-    KMFilterAction* classSpamFilterActionFirst = dict.value( "set status" )->create();
+    QList<FilterAction*> *classSpamFilterActions = classSpamFilter->actions();
+    FilterAction* classSpamFilterActionFirst = dict.value( "set status" )->create();
     classSpamFilterActionFirst->argsFromString( "P" );
     classSpamFilterActions->append( classSpamFilterActionFirst );
     for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
@@ -372,25 +386,25 @@ void AntiSpamWizard::accept()
       if ( mInfoPage->isProgramSelected( (*it).getVisibleName() )
           && (*it).useBayesFilter() && !(*it).isDetectionOnly() )
       {
-        KMFilterAction* classSpamFilterAction = dict.value( "execute" )->create();
+        FilterAction* classSpamFilterAction = dict.value( "execute" )->create();
         classSpamFilterAction->argsFromString( (*it).getSpamCmd() );
         classSpamFilterActions->append( classSpamFilterAction );
       }
     }
     if ( mSpamRulesPage->moveSpamSelected() )
     {
-      KMFilterAction* classSpamFilterActionLast = dict.value( "transfer" )->create();
-      classSpamFilterActionLast->argsFromString( mSpamRulesPage->selectedSpamFolderName() );
+      FilterAction* classSpamFilterActionLast = dict.value( "transfer" )->create();
+      classSpamFilterActionLast->argsFromString( mSpamRulesPage->selectedSpamCollectionId() );
       classSpamFilterActions->append( classSpamFilterActionLast );
     }
 
-    KMSearchPattern* classSpamFilterPattern = classSpamFilter->pattern();
+    SearchPattern* classSpamFilterPattern = classSpamFilter->pattern();
     if ( replaceExistingFilters )
       classSpamFilterPattern->setName( i18n( "Classify as Spam" ) );
     else
       classSpamFilterPattern->setName( uniqueNameFor( i18n( "Classify as Spam" ) ) );
-    classSpamFilterPattern->append( KMSearchRule::createInstance( "<size>",
-                                    KMSearchRule::FuncIsGreaterOrEqual, "0" ) );
+    classSpamFilterPattern->append( SearchRule::createInstance( "<size>",
+                                    SearchRule::FuncIsGreaterOrEqual, "0" ) );
     classSpamFilter->setApplyOnOutbound( false);
     classSpamFilter->setApplyOnInbound( false );
     classSpamFilter->setApplyOnExplicit( false );
@@ -401,10 +415,10 @@ void AntiSpamWizard::accept()
     filterList.append( classSpamFilter );
 
     // Classify messages manually as not Spam / as Ham
-    KMFilter* classHamFilter = new KMFilter();
+    MailFilter* classHamFilter = new MailFilter();
     classHamFilter->setIcon( "mail-mark-notjunk" );
-    QList<KMFilterAction*> *classHamFilterActions = classHamFilter->actions();
-    KMFilterAction* classHamFilterActionFirst = dict.value( "set status" )->create();
+    QList<FilterAction*> *classHamFilterActions = classHamFilter->actions();
+    FilterAction* classHamFilterActionFirst = dict.value( "set status" )->create();
     classHamFilterActionFirst->argsFromString( "H" );
     classHamFilterActions->append( classHamFilterActionFirst );
     for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
@@ -412,7 +426,7 @@ void AntiSpamWizard::accept()
       if ( mInfoPage->isProgramSelected( (*it).getVisibleName() )
           && (*it).useBayesFilter() && !(*it).isDetectionOnly() )
       {
-        KMFilterAction* classHamFilterAction = dict.value( "execute" )->create();
+        FilterAction* classHamFilterAction = dict.value( "execute" )->create();
         classHamFilterAction->argsFromString( (*it).getHamCmd() );
         classHamFilterActions->append( classHamFilterAction );
       }
@@ -422,18 +436,18 @@ void AntiSpamWizard::accept()
       if ( mInfoPage->isProgramSelected( (*it).getVisibleName() )
           && (*it).useBayesFilter() && !(*it).isDetectionOnly() )
       {
-        KMFilterAction* classHamFilterAction = dict.value( "filter app" )->create();
+        FilterAction* classHamFilterAction = dict.value( "filter app" )->create();
         classHamFilterAction->argsFromString( (*it).getNoSpamCmd() );
         classHamFilterActions->append( classHamFilterAction );
       }
     }
-    KMSearchPattern* classHamFilterPattern = classHamFilter->pattern();
+    SearchPattern* classHamFilterPattern = classHamFilter->pattern();
     if ( replaceExistingFilters )
       classHamFilterPattern->setName( i18n( "Classify as NOT Spam" ) );
     else
       classHamFilterPattern->setName( uniqueNameFor( i18n( "Classify as NOT Spam" ) ) );
-    classHamFilterPattern->append( KMSearchRule::createInstance( "<size>",
-                                    KMSearchRule::FuncIsGreaterOrEqual, "0" ) );
+    classHamFilterPattern->append( SearchRule::createInstance( "<size>",
+                                    SearchRule::FuncIsGreaterOrEqual, "0" ) );
     classHamFilter->setApplyOnOutbound( false);
     classHamFilter->setApplyOnInbound( false );
     classHamFilter->setApplyOnExplicit( false );
@@ -449,7 +463,7 @@ void AntiSpamWizard::accept()
    * which will result in the filter list in kmmainwidget being
    * initialized. This should happend only once. */
   if ( !filterList.isEmpty() )
-    KMKernel::self()->filterMgr()->appendFilters(
+    KMKernel::self()->filterManager()->appendFilters(
           filterList, replaceExistingFilters );
 
   KDialog::accept();
@@ -480,13 +494,17 @@ void AntiSpamWizard::checkProgramsSelections()
 
   if ( mMode == AntiSpam ) {
     mSpamRulesPage->allowUnsureFolderSelection( supportUnsure );
+    mSpamRulesPage->allowMoveSpam( mSpamToolsUsed );
     slotBuildSummary();
+    setAppropriate( mSpamRulesPageItem, mSpamToolsUsed );
+    setAppropriate( mSummaryPageItem, mSpamToolsUsed );
   }
 
-  if ( ( mMode == AntiVirus ) && mVirusToolsUsed )
-    checkVirusRulesSelections();
-
-  //setNextEnabled( mInfoPage, status );
+  if ( mMode == AntiVirus ) {
+    if ( mVirusToolsUsed )
+      checkVirusRulesSelections();
+    setAppropriate( mVirusRulesPageItem, mVirusToolsUsed );
+  }
 }
 
 
@@ -499,7 +517,7 @@ void AntiSpamWizard::checkVirusRulesSelections()
 void AntiSpamWizard::checkToolAvailability()
 {
   // this can take some time to find the tools
-  KCursorSaver busy( KBusyPtr::busy() );
+  MessageViewer::KCursorSaver busy( MessageViewer::KBusyPtr::busy() );
 
   bool found = false;
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
@@ -509,21 +527,32 @@ void AntiSpamWizard::checkToolAvailability()
     if ( (*it).isSpamTool() && (*it).isServerBased() ) {
       // check the configured account for pattern in <server>
       QString pattern = (*it).getServerPattern();
-      kDebug() <<"Testing for server pattern:" << pattern;
-
-      AccountManager* mgr = kmkernel->acctMgr();
-      QList<KMAccount*>::iterator accountIt = mgr->begin();
-      while ( accountIt != mgr->end() ) {
-        KMAccount *account = *accountIt;
-        ++accountIt;
-        if ( account->type() == KAccount::Pop ||
-             account->type() == KAccount::Imap ||
-             account->type() == KAccount::DImap ) {
-          const NetworkAccount * n = dynamic_cast<const NetworkAccount*>( account );
-          if ( n && n->host().toLower().contains( pattern.toLower() ) ) {
-            mInfoPage->addAvailableTool( (*it).getVisibleName() );
-            found = true;
+      kDebug() << "Testing for server pattern:" << pattern;
+      const Akonadi::AgentInstance::List lst = MailCommon::Util::agentInstances();
+      foreach( const Akonadi::AgentInstance& type, lst ) {
+        if ( type.status() == Akonadi::AgentInstance::Broken )
+          continue;
+        if ( type.identifier().contains( IMAP_RESOURCE_IDENTIFIER ) ) {
+          OrgKdeAkonadiImapSettingsInterface *iface = MailCommon::Util::createImapSettingsInterface( type.identifier() );
+          if ( iface->isValid() ) {
+            QString host = iface->imapServer();
+            if ( host.toLower().contains( pattern.toLower() ) ) {
+              mInfoPage->addAvailableTool( (*it).getVisibleName() );
+              found = true;
+            }
           }
+          delete iface;
+        }
+        else if ( type.identifier().contains( POP3_RESOURCE_IDENTIFIER ) ) {
+          OrgKdeAkonadiPOP3SettingsInterface *iface = new OrgKdeAkonadiPOP3SettingsInterface("org.freedesktop.Akonadi.Resource." + type.identifier(), "/Settings", QDBusConnection::sessionBus() );
+          if ( iface->isValid() ) {
+            QString host = iface->host();
+            if ( host.toLower().contains( pattern.toLower() ) ) {
+              mInfoPage->addAvailableTool( (*it).getVisibleName() );
+              found = true;
+            }
+          }
+          delete iface;
         }
       }
     }
@@ -540,12 +569,14 @@ void AntiSpamWizard::checkToolAvailability()
     mInfoPage->setScanProgressText( ( mMode == AntiSpam )
                                     ? i18n("Scanning for anti-spam tools finished.")
                                     : i18n("Scanning for anti-virus tools finished.") );
-  else
+  else {
     mInfoPage->setScanProgressText( ( mMode == AntiSpam )
                                     ? i18n("<p>Sorry, no spam detection tools have been found. "
                                            "Install your spam detection software and "
                                            "re-run this wizard.</p>")
                                     : i18n("Scanning complete. No anti-virus tools found.") );
+  }
+  checkProgramsSelections();
 }
 
 
@@ -572,7 +603,7 @@ void AntiSpamWizard::slotBuildSummary()
       if ( mSpamRulesPage->moveSpamSelected() )
         text = i18n( "<p>Messages classified as spam are marked as read."
                      "<br />Spam messages are moved into the folder named <i>%1</i>.</p>"
-                     , mSpamRulesPage->selectedSpamFolderName() );
+                     , mSpamRulesPage->selectedSpamCollectionName() );
       else
         text = i18n( "<p>Messages classified as spam are marked as read."
                      "<br />Spam messages are not moved into a certain folder.</p>" );
@@ -581,7 +612,7 @@ void AntiSpamWizard::slotBuildSummary()
       if ( mSpamRulesPage->moveSpamSelected() )
         text = i18n( "<p>Messages classified as spam are not marked as read."
                      "<br />Spam messages are moved into the folder named <i>%1</i>.</p>"
-                     , mSpamRulesPage->selectedSpamFolderName() );
+                     , mSpamRulesPage->selectedSpamCollectionName() );
       else
         text = i18n( "<p>Messages classified as spam are not marked as read."
                      "<br />Spam messages are not moved into a certain folder.</p>" );
@@ -610,7 +641,7 @@ void AntiSpamWizard::slotBuildSummary()
         sortFilterOnExistance( i18n( "Semi spam (unsure) handling" ),
                                newFilters, replaceFilters );
         text += i18n( "<p>The folder for messages classified as unsure (probably spam) is <i>%1</i>.</p>"
-          , mSpamRulesPage->selectedUnsureFolderName() );
+          , mSpamRulesPage->selectedUnsureCollectionName() );
       }
     }
 
@@ -635,7 +666,7 @@ void AntiSpamWizard::slotBuildSummary()
 
 int AntiSpamWizard::checkForProgram( const QString &executable )
 {
-  kDebug() <<"Testing for executable:" << executable;
+  kDebug() << "Testing for executable:" << executable;
   KProcess process;
   process.setShellCommand( executable );
   return process.execute ();
@@ -651,7 +682,7 @@ bool AntiSpamWizard::anyVirusOptionChecked()
 
 const QString AntiSpamWizard::uniqueNameFor( const QString & name )
 {
-  return KMKernel::self()->filterMgr()->createUniqueName( name );
+  return KMKernel::self()->filterManager()->createUniqueName( name );
 }
 
 
@@ -699,14 +730,13 @@ AntiSpamWizard::ConfigReader::ConfigReader( WizardMode mode,
     mMode( mode )
 {
   if ( mMode == AntiSpam )
-    mConfig = new KConfig( "kmail.antispamrc" );
+    mConfig = KSharedConfig::openConfig( "kmail.antispamrc" );
   else
-    mConfig = new KConfig( "kmail.antivirusrc" );
+    mConfig = KSharedConfig::openConfig( "kmail.antivirusrc" );
 }
 
 AntiSpamWizard::ConfigReader::~ConfigReader( )
 {
-  delete mConfig;
 }
 
 
@@ -754,8 +784,8 @@ AntiSpamWizard::SpamToolConfig
   QString id = configGroup.readEntry( "Ident" );
   int version = configGroup.readEntry( "Version", 0 );
 #ifndef NDEBUG
-  kDebug() <<"Found predefined tool:" << id;
-  kDebug() <<"With config version  :" << version;
+  kDebug() << "Found predefined tool:" << id;
+  kDebug() << "With config version  :" << version;
 #endif
   int prio = configGroup.readEntry( "Priority", 1 );
   QString name = configGroup.readEntry( "VisibleName" );
@@ -802,8 +832,8 @@ void AntiSpamWizard::ConfigReader::mergeToolConfig( AntiSpamWizard::SpamToolConf
   for ( QList<SpamToolConfig>::Iterator it = mToolList.begin();
         it != mToolList.end(); ++it ) {
 #ifndef NDEBUG
-    kDebug() <<"Check against tool:" << (*it).getId();
-    kDebug() <<"Against version   :" << (*it).getVersion();
+    kDebug() << "Check against tool:" << (*it).getId();
+    kDebug() << "Against version   :" << (*it).getVersion();
 #endif
     if ( (*it).getId() == config.getId() )
     {
@@ -811,7 +841,7 @@ void AntiSpamWizard::ConfigReader::mergeToolConfig( AntiSpamWizard::SpamToolConf
       if ( (*it).getVersion() < config.getVersion() )
       {
 #ifndef NDEBUG
-        kDebug() <<"Replacing config ...";
+        kDebug() << "Replacing config ...";
 #endif
         mToolList.erase( it );
         mToolList.append( config );
@@ -943,8 +973,7 @@ void ASWizInfoPage::setScanProgressText( const QString &toolName )
 
 void ASWizInfoPage::addAvailableTool( const QString &visibleName )
 {
-  QString listName = visibleName;
-  mToolsList->addItem( listName );
+  mToolsList->addItem( visibleName );
   if ( !mToolsList->isVisible() )
   {
     mToolsList->show();
@@ -972,8 +1001,7 @@ void ASWizInfoPage::processSelectionChange()
 
 
 //---------------------------------------------------------------------------
-ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
-                                        MainFolderView * mainFolderTree )
+ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name)
   : ASWizPage( parent, name )
 {
   QVBoxLayout *layout = new QVBoxLayout();
@@ -991,8 +1019,7 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
   layout->addWidget( mMoveSpamRules );
 
   mFolderReqForSpamFolder = new FolderRequester( this );
-  mFolderReqForSpamFolder->setFolderTree( mainFolderTree );
-  mFolderReqForSpamFolder->setFolder( "trash" );
+  mFolderReqForSpamFolder->setFolder( CommonKernel->trashCollectionFolder() );
   mFolderReqForSpamFolder->setMustBeReadWrite( true );
   mFolderReqForSpamFolder->setShowOutbox( false );
   mFolderReqForSpamFolder->setShowImapFolders( false );
@@ -1011,7 +1038,6 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
   layout->addWidget( mMoveUnsureRules );
 
   mFolderReqForUnsureFolder = new FolderRequester( this );
-  mFolderReqForUnsureFolder->setFolderTree( mainFolderTree );
   mFolderReqForUnsureFolder->setFolder( "inbox" );
   mFolderReqForUnsureFolder->setMustBeReadWrite( true );
   mFolderReqForUnsureFolder->setShowOutbox( false );
@@ -1030,10 +1056,10 @@ ASWizSpamRulesPage::ASWizSpamRulesPage( QWidget * parent, const char * name,
             this, SLOT(processSelectionChange(void)) );
   connect( mMoveUnsureRules, SIGNAL(clicked()),
             this, SLOT(processSelectionChange(void)) );
-  connect( mFolderReqForSpamFolder, SIGNAL(folderChanged(KMFolder*)),
-            this, SLOT(processSelectionChange(KMFolder*)) );
-  connect( mFolderReqForUnsureFolder, SIGNAL(folderChanged(KMFolder*)),
-            this, SLOT(processSelectionChange(KMFolder*)) );
+  connect( mFolderReqForSpamFolder, SIGNAL(folderChanged(const Akonadi::Collection &)),
+           this, SLOT(processSelectionChange(const Akonadi::Collection &)) );
+  connect( mFolderReqForUnsureFolder, SIGNAL(folderChanged(const Akonadi::Collection &)),
+           this, SLOT(processSelectionChange(const Akonadi::Collection&)) );
 
   mMarkRules->setChecked( true );
   mMoveSpamRules->setChecked( true );
@@ -1057,22 +1083,41 @@ bool ASWizSpamRulesPage::moveUnsureSelected() const
   return mMoveUnsureRules->isChecked();
 }
 
-
-QString ASWizSpamRulesPage::selectedSpamFolderName() const
+QString ASWizSpamRulesPage::selectedSpamCollectionId() const
 {
-  QString name = "trash";
-  if ( mFolderReqForSpamFolder->folder() )
-    name = mFolderReqForSpamFolder->folder()->idString();
-  return name;
+  return QString::number( selectedSpamCollection().id() );
+}
+
+QString ASWizSpamRulesPage::selectedSpamCollectionName() const
+{
+  return selectedSpamCollection().name();
+}
+
+Akonadi::Collection ASWizSpamRulesPage::selectedSpamCollection() const
+{
+  if ( mFolderReqForSpamFolder->folderCollection().isValid() )
+    return mFolderReqForSpamFolder->folderCollection();
+  else
+    return CommonKernel->trashCollectionFolder();
 }
 
 
-QString ASWizSpamRulesPage::selectedUnsureFolderName() const
+Akonadi::Collection ASWizSpamRulesPage::selectedUnsureCollection() const
 {
-  QString name = "inbox";
-  if ( mFolderReqForUnsureFolder->folder() )
-    name = mFolderReqForUnsureFolder->folder()->idString();
-  return name;
+  if ( mFolderReqForUnsureFolder->folderCollection().isValid() )
+    return mFolderReqForUnsureFolder->folderCollection();
+  else
+    return CommonKernel->inboxCollectionFolder();
+}
+
+QString ASWizSpamRulesPage::selectedUnsureCollectionName() const
+{
+  return selectedUnsureCollection().name();
+}
+
+QString ASWizSpamRulesPage::selectedUnsureCollectionId() const
+{
+  return QString::number( selectedUnsureCollection().id() );
 }
 
 
@@ -1084,7 +1129,7 @@ void ASWizSpamRulesPage::processSelectionChange()
 }
 
 
-void ASWizSpamRulesPage::processSelectionChange( KMFolder* )
+void ASWizSpamRulesPage::processSelectionChange( const Akonadi::Collection& )
 {
   processSelectionChange();
 }
@@ -1098,10 +1143,17 @@ void ASWizSpamRulesPage::allowUnsureFolderSelection( bool enabled )
   mFolderReqForUnsureFolder->setVisible( enabled );
 }
 
+void ASWizSpamRulesPage::allowMoveSpam( bool enabled )
+{
+  mMarkRules->setEnabled( enabled );
+  mMarkRules->setChecked( enabled );
+  mMoveSpamRules->setEnabled( enabled  );
+  mMoveSpamRules->setChecked( enabled  );
+}
+
 
 //---------------------------------------------------------------------------
-ASWizVirusRulesPage::ASWizVirusRulesPage( QWidget * parent, const char * name,
-                                  MainFolderView * mainFolderTree )
+ASWizVirusRulesPage::ASWizVirusRulesPage( QWidget * parent, const char * name )
   : ASWizPage( parent, name )
 {
   QGridLayout *grid = new QGridLayout();
@@ -1131,9 +1183,22 @@ ASWizVirusRulesPage::ASWizVirusRulesPage( QWidget * parent, const char * name,
             "virus-infected as read, as well as moving them "
             "to the selected folder.") );
   grid->addWidget( mMarkRules, 2, 0 );
+  FolderTreeWidget::TreeViewOptions opt = FolderTreeWidget::None;
+  opt |= FolderTreeWidget::UseDistinctSelectionModel;
 
-  mFolderTree = new FolderSelectionTreeWidget( this, mainFolderTree );
-  mFolderTree->reload( true, true, true, QString( "trash" ) );
+  ReadableCollectionProxyModel::ReadableCollectionOptions optReadableProxy = ReadableCollectionProxyModel::None;
+  optReadableProxy |= ReadableCollectionProxyModel::HideVirtualFolder;
+  optReadableProxy |= ReadableCollectionProxyModel::HideOutboxFolder;
+  optReadableProxy |= ReadableCollectionProxyModel::HideImapFolder;
+
+  mFolderTree = new FolderTreeWidget( this, 0, opt, optReadableProxy );
+  mFolderTree->folderTreeView()->expandAll();
+  mFolderTree->readableCollectionProxyModel()->setAccessRights( Akonadi::Collection::CanCreateCollection );
+
+  mFolderTree->selectCollectionFolder( CommonKernel->trashCollectionFolder() );
+  mFolderTree->folderTreeView()->setDragDropMode( QAbstractItemView::NoDragDrop );
+
+  mFolderTree->disableContextMenuAndExtraColumn();
   grid->addWidget( mFolderTree, 3, 0 );
 
   connect( mPipeRules, SIGNAL(clicked()),
@@ -1166,10 +1231,10 @@ bool ASWizVirusRulesPage::markReadRulesSelected() const
 
 QString ASWizVirusRulesPage::selectedFolderName() const
 {
-  QString name = "trash";
-  if ( mFolderTree->folder() )
-    name = mFolderTree->folder()->idString();
-  return name;
+  if ( mFolderTree->selectedCollection().isValid() )
+    return QString::number( mFolderTree->selectedCollection().id() );
+  else
+    return QString::number( CommonKernel->trashCollectionFolder().id() );
 }
 
 void ASWizVirusRulesPage::processSelectionChange()
