@@ -98,10 +98,11 @@ class MessageActions : public QObject
   private:
     void updateActions();
     template<typename T> void replyCommand();
-    void setMessageStatus( KPIM::MessageStatus status, bool toggle = false );
     void addMailingListAction( const QString &item, const KUrl &url );
     void addMailingListActions( const QString &item, const KUrl::List &list );
     void updateAnnotateAction();
+    void updateMailingListActions( const Akonadi::Item& messageItem );
+    
   private slots:
     void slotItemModified( const Akonadi::Item &  item, const QSet< QByteArray > &  partIdentifiers );
     void slotReplyToMsg();
@@ -110,12 +111,9 @@ class MessageActions : public QObject
     void slotReplyAllToMsg();
     void slotNoQuoteReplyToMsg();
     void slotCreateTodo();
-    void slotSetMsgStatusUnread();
-    void slotSetMsgStatusRead();
-    void slotSetMsgStatusToAct();
-    void slotSetMsgStatusFlag();
     void slotRunUrl( QAction *urlAction );
     void slotPrintMsg();
+    void slotUpdateActionsFetchDone( KJob* job );
 
   private:
     QWidget *mParent;
@@ -133,7 +131,6 @@ class MessageActions : public QObject
     KActionMenu *mStatusMenu;
     KActionMenu *mForwardActionMenu;
     KActionMenu *mMailingListActionMenu;
-    KToggleAction *mToggleFlagAction, *mToggleToActAction;
     KAction *mEditAction, *mAnnotateAction, *mPrintAction;
     bool mKorganizerIsOnSystem;
     Akonadi::Monitor *mMonitor;
