@@ -15,18 +15,15 @@
 #ifndef KNARTICLE_H
 #define KNARTICLE_H
 
+#include "knjobdata.h"
+
+#include <boost/shared_ptr.hpp>
 #include <QFile>
 #include <QColor>
-#include <q3asciidict.h>
-#include <QList>
-
 #include <kmime/kmime_headers.h>
 #include <kmime/kmime_newsarticle.h>
 #include <kmime/boolflags.h>
 
-#include "knjobdata.h"
-
-//forward declarations
 class KNLoadHelper;
 class KNHdrViewItem;
 class KNArticleCollection;
@@ -35,12 +32,13 @@ class KNArticleCollection;
     usual headers of a RFC822-message. Further more it contains an
     unique id and can store a pointer to a @ref QListViewItem. It is
     used as a base class for all visible articles. */
-
 class KNArticle : public KMime::NewsArticle, public KNJobItem {
 
   public:
+    /// Shared pointer to a KNArticle. To be used instead of raw KNArticle*.
+    typedef boost::shared_ptr<KNArticle> Ptr;
     /// List of articles.
-    typedef QList<KNArticle*> List;
+    typedef QList<KNArticle::Ptr> List;
 
     enum articleType {
       ATmimeContent,
@@ -48,7 +46,7 @@ class KNArticle : public KMime::NewsArticle, public KNJobItem {
       ATlocal
     };
 
-    KNArticle(KNArticleCollection *c);
+    KNArticle( boost::shared_ptr<KNArticleCollection> c );
     ~KNArticle();
 
     virtual void clear();
@@ -64,7 +62,12 @@ class KNArticle : public KMime::NewsArticle, public KNJobItem {
 
     //list item handling
     KNHdrViewItem* listItem() const           { return i_tem; }
-    void setListItem(KNHdrViewItem *i);
+    /**
+      Sets the headerview item associated to this article.
+      @param i The item associated to this item or 0 to break the link to the previous item.
+      @param a The shared pointer of <strong>this</strong> article.
+    */
+    void setListItem( KNHdrViewItem *i, KNArticle::Ptr a );
     virtual void updateListItem() {}
 
     //network lock (reimplemented from KNJobItem)
@@ -76,14 +79,13 @@ class KNArticle : public KMime::NewsArticle, public KNJobItem {
     void setNotUnloadable(bool b=true)   { f_lags.set(1, b); }
 
     //article-collection
-    KNArticleCollection* collection() const          { return c_ol; }
-    void setCollection(KNArticleCollection *c)  { c_ol=c; }
+    boost::shared_ptr<KNArticleCollection> collection() const { return c_ol; }
+    void setCollection( boost::shared_ptr<KNArticleCollection> c ) { c_ol = c; }
     bool isOrphant() const                           { return (i_d==-1); }
 
   protected:
-    virtual QByteArray assembleHeaders();
     int i_d; //unique in the given collection
-    KNArticleCollection *c_ol;
+    boost::shared_ptr<KNArticleCollection> c_ol;
     KNHdrViewItem *i_tem;
 
     KMime::BoolFlags f_lags;
@@ -101,10 +103,12 @@ class KNGroup;
 class KNRemoteArticle : public KNArticle {
 
   public:
+    /// Shared pointer to a KNRemoteArticle. To be used instead of raw KNRemoteArticle*.
+    typedef boost::shared_ptr<KNRemoteArticle> Ptr;
     /// List of remote articles.
-    typedef QList<KNRemoteArticle*> List;
+    typedef QList<KNRemoteArticle::Ptr> List;
 
-    KNRemoteArticle(KNGroup *g);
+    KNRemoteArticle( boost::shared_ptr<KNGroup> g );
     ~KNRemoteArticle();
 
     // type
@@ -112,16 +116,6 @@ class KNRemoteArticle : public KNArticle {
 
     // content handling
     virtual void parse();
-    virtual void assemble() {} //assembling is disabled for remote articles
-    virtual void clear();
-
-    // header access
-    KMime::Headers::Base* headerByType(const char *type);
-    void setHeader(KMime::Headers::Base *h);
-    bool removeHeader(const char *type);
-    KMime::Headers::MessageID* messageID(bool create=true)   { if(!create && m_essageID.isEmpty()) return 0; return &m_essageID; }
-    KMime::Headers::From* from(bool create=true)             { if(!create && f_rom.isEmpty()) return 0; return &f_rom; }
-    KMime::Headers::References* references(bool create=true) { if(!create && r_eferences.isEmpty()) return 0; return &r_eferences; }
 
     // article number
     int articleNumber() const                 { return a_rticleNumber; }
@@ -150,8 +144,8 @@ class KNRemoteArticle : public KNArticle {
                                                         i_dRef=i;
                                                       else
                                                         i_dRef=0; }
-    KNRemoteArticle* displayedReference()           { return d_ref; }
-    void setDisplayedReference(KNRemoteArticle *dr) { d_ref=dr; }
+    KNRemoteArticle::Ptr displayedReference()           { return d_ref; }
+    void setDisplayedReference( KNRemoteArticle::Ptr dr ) { d_ref=dr; }
     bool threadMode()                             { return f_lags.get(9); }
     void setThreadMode(bool b=true)               { f_lags.set(9, b); }
     unsigned char threadingLevel()                { return t_hrLevel; }
@@ -193,14 +187,9 @@ class KNRemoteArticle : public KNArticle {
     void propagateThreadChangedDate();
 
   protected:
-    // hardcoded headers
-    KMime::Headers::MessageID m_essageID;
-    KMime::Headers::From f_rom;
-    KMime::Headers::References r_eferences;
-
     int a_rticleNumber;
     int i_dRef;                      // id of a reference-article (0 == none)
-    KNRemoteArticle *d_ref;          // displayed reference-article (may differ from i_dRef)
+    KNRemoteArticle::Ptr d_ref;      // displayed reference-article (may differ from i_dRef)
     unsigned char t_hrLevel;         // quality of threading
     short s_core;                    // guess what ;-)
     QColor c_olor;                   // color for the header list
@@ -221,32 +210,17 @@ class KNRemoteArticle : public KNArticle {
 class KNLocalArticle : public KNArticle {
 
   public:
+    /// Shared pointer to a KNLocalArticle. To be used instead of raw KNLocalArticle*.
+    typedef boost::shared_ptr<KNLocalArticle> Ptr;
     /// List of local articles.
-    typedef QList<KNLocalArticle*> List;
+    typedef QList<KNLocalArticle::Ptr> List;
 
-    KNLocalArticle(KNArticleCollection *c=0);
+    KNLocalArticle( boost::shared_ptr<KNArticleCollection> c = boost::shared_ptr<KNArticleCollection>() );
     ~KNLocalArticle();
 
     //type
     articleType type() const { return ATlocal; }
 
-    //content handling
-    void parse();
-    void clear();
-
-    // header access
-    KMime::Headers::Base* headerByType(const char *type);
-    void setHeader(KMime::Headers::Base *h);
-    bool removeHeader(const char *type);
-    KMime::Headers::Newsgroups* newsgroups(bool create=true)     { if ( (!create && n_ewsgroups.isEmpty()) ||
-                                                                   (!create && !isSavedRemoteArticle() && !doPost()) )
-                                                                return 0;
-                                                              return &n_ewsgroups; }
-    KMime::Headers::To* to(bool create=true)                     { if ( (!create && t_o.isEmpty()) ||
-                                                                   (!create && !isSavedRemoteArticle() && !doMail()) )
-                                                                return 0;
-                                                              return &t_o; }
-
     //send article as mail
     bool doMail()                 { return f_lags.get(2); }
     void setDoMail(bool b=true)   { f_lags.set(2, b); }
@@ -273,7 +247,7 @@ class KNLocalArticle : public KNArticle {
     bool filterResult()                { return f_lags.get(8); }
     void setFilterResult(bool b=true)  { f_lags.set(8, b); }
 
-    //MBOX infos
+    //MBOX information
     int startOffset() const             { return s_Offset; }
     void setStartOffset(int so)   { s_Offset=so; }
     int endOffset() const              { return e_Offset; }
@@ -289,9 +263,6 @@ class KNLocalArticle : public KNArticle {
     virtual void setForceDefaultCharset(bool b);
 
     protected:
-      //hardcoded headers
-      KMime::Headers::Newsgroups n_ewsgroups;
-      KMime::Headers::To t_o;
       int s_Offset, //position in mbox-file : start
           e_Offset, //position in mbox-file : end
           s_erverId; //id of the nntp-server this article is posted to
@@ -304,6 +275,11 @@ class KNLocalArticle : public KNArticle {
 class KNAttachment {
 
   public:
+    /**
+      Shared pointer to a KNAttachment. To be used instead of raw KNAttachment*.
+    */
+    typedef boost::shared_ptr<KNAttachment> Ptr;
+
     KNAttachment(KMime::Content *c);
     KNAttachment(KNLoadHelper *helper);
     ~KNAttachment();
