@@ -39,11 +39,13 @@ class KNFilterManager;
 class KNMainWidget;
 class KNScoringManager;
 class KNMemoryManager;
-class KXMLGUIClient;
 namespace KNode {
   class Scheduler;
   class Settings;
 }
+namespace KPIMIdentities {
+  class IdentityManager;
+}
 
 
 /** idea: Previously the manager classes were available
@@ -62,10 +64,9 @@ class KNODE_EXPORT KNGlobals
     QWidget               *topWidget;
     /** no need to include knode.h everywhere */
     KNMainWidget          *top;
-    /** Returns the KXMLGUIClient of the main window. */
-    KXMLGUIClient         *guiClient;
+
     /** Returns the article factory. */
-    KNArticleFactory      *artFactory;
+    KNArticleFactory *articleFactory();
     /** Returns KNode's main configuration. */
     KConfig               *config();
     /** Returns the current instance. */
@@ -92,6 +93,9 @@ class KNODE_EXPORT KNGlobals
     KNMemoryManager       *memoryManager();
     /** Returns the KConfigXT generated settings object. */
     KNode::Settings *settings();
+    /** Returns the identity manager. */
+    KPIMIdentities::IdentityManager *identityManager();
+
 
     /** forwarded to top->setStatusMsg() if available */
     void setStatusMsg(const QString& text = QString(), int id = SB_MAIN);
@@ -115,6 +119,8 @@ class KNODE_EXPORT KNGlobals
     KNScoringManager *mScoreManager;
     KNMemoryManager       *mMemManager;
     KNode::Settings *mSettings;
+    KNArticleFactory *mArticleFactory;
+    KPIMIdentities::IdentityManager * mIdentityManager;
 };
 
 #endif
