@@ -21,27 +21,26 @@
 */
 
 #include "iconsidepane.h"
-#include "mainwindow.h"
-#include "plugin.h"
 #include "prefs.h"
+using namespace Kontact;
 
-#include <QtCore/QTimer>
-#include <QtGui/QStringListModel>
-#include <QtGui/QSortFilterProxyModel>
-#include <QtGui/QDragEnterEvent>
-#include <QtGui/QDragMoveEvent>
-#include <QtGui/QStyledItemDelegate>
-#include <QtGui/QScrollBar>
+#include <KontactInterface/Core>
+#include <KontactInterface/Plugin>
 
-#include <KLocalizedString>
-#include <KStringHandler>
-#include <KDialog>
+#include <KAction>
 #include <KIcon>
+#include <KLocale>
+#include <KStringHandler>
 
-namespace Kontact
-{
+#include <QDragEnterEvent>
+#include <QDragMoveEvent>
+#include <QDropEvent>
+#include <QSortFilterProxyModel>
+#include <QStringListModel>
+#include <QStyledItemDelegate>
+#include <QTimer>
 
-class Navigator;
+namespace Kontact {
 
 class SelectionModel : public QItemSelectionModel
 {
@@ -91,12 +90,12 @@ class Model : public QStringListModel
     {
     }
 
-    void emitLayoutChanged()
+    void emitReset()
     {
-        emit layoutChanged();
+        emit reset();
     }
 
-    void setPluginList( const QList<Kontact::Plugin*> &list ) {
+    void setPluginList( const QList<KontactInterface::Plugin*> &list ) {
       pluginList = list;
     }
 
@@ -107,7 +106,7 @@ class Model : public QStringListModel
       flags &= ~Qt::ItemIsEditable;
 
       if ( index.isValid() ) {
-        if ( static_cast<Kontact::Plugin*>( index.internalPointer() )->disabled() ) {
+        if ( static_cast<KontactInterface::Plugin*>( index.internalPointer() )->disabled() ) {
           flags &= ~Qt::ItemIsEnabled;
           flags &= ~Qt::ItemIsSelectable;
           flags &= ~Qt::ItemIsDropEnabled;
@@ -141,27 +140,27 @@ class Model : public QStringListModel
         if ( !mNavigator->showText() ) {
           return QVariant();
         }
-        return static_cast<Kontact::Plugin*>( index.internalPointer() )->title();
+        return static_cast<KontactInterface::Plugin*>( index.internalPointer() )->title();
       } else if ( role == Qt::DecorationRole ) {
         if ( !mNavigator->showIcons() ) {
           return QVariant();
         }
-        return KIcon( static_cast<Kontact::Plugin*>( index.internalPointer() )->icon() );
+        return KIcon( static_cast<KontactInterface::Plugin*>( index.internalPointer() )->icon() );
       } else if ( role == Qt::TextAlignmentRole ) {
         return Qt::AlignCenter;
       } else if ( role == Qt::ToolTipRole ) {
         if ( !mNavigator->showText() ) {
-          return static_cast<Kontact::Plugin*>( index.internalPointer() )->title();
+          return static_cast<KontactInterface::Plugin*>( index.internalPointer() )->title();
         }
         return QVariant();
       } else if ( role == PluginName ) {
-        return static_cast<Kontact::Plugin*>( index.internalPointer() )->identifier();
+        return static_cast<KontactInterface::Plugin*>( index.internalPointer() )->identifier();
       }
       return QStringListModel::data( index, role );
     }
 
   private:
-    QList<Kontact::Plugin*> pluginList;
+    QList<KontactInterface::Plugin*> pluginList;
     Navigator *mNavigator;
 };
 
@@ -177,8 +176,10 @@ class SortFilterProxyModel
   protected:
     bool lessThan( const QModelIndex &left, const QModelIndex &right ) const
     {
-      Kontact::Plugin *leftPlugin = static_cast<Kontact::Plugin*>( left.internalPointer() );
-      Kontact::Plugin *rightPlugin = static_cast<Kontact::Plugin*>( right.internalPointer() );
+      KontactInterface::Plugin *leftPlugin =
+        static_cast<KontactInterface::Plugin*>( left.internalPointer() );
+      KontactInterface::Plugin *rightPlugin =
+        static_cast<KontactInterface::Plugin*>( right.internalPointer() );
 
       if ( leftPlugin->weight() == rightPlugin->weight() ) {
         return KStringHandler::naturalCompare( leftPlugin->title(), rightPlugin->title() ) < 0;
@@ -228,6 +229,8 @@ class Delegate : public QStyledItemDelegate
     Navigator *mNavigator;
 };
 
+}
+
 Navigator::Navigator( SidePaneBase *parent )
   : QListView( parent ), mSidePane( parent )
 {
@@ -242,22 +245,40 @@ Navigator::Navigator( SidePaneBase *parent )
 
   QActionGroup *viewMode = new QActionGroup( this );
 
-  mShowIconsAction = new KAction( i18n( "Show Icons Only" ), this );
+  mShowIconsAction = new KAction( i18nc( "@action:inmenu", "Show Icons Only" ), this );
   mShowIconsAction->setCheckable( true );
   mShowIconsAction->setActionGroup( viewMode );
   mShowIconsAction->setChecked( !mShowText && mShowIcons );
+  mShowIconsAction->setHelpText(
+    i18nc( "@info:status",
+           "Show sidebar items with icons and without text" ) );
+  mShowIconsAction->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Choose this option if you want the sidebar items to have icons without text." ) );
   connect( mShowIconsAction, SIGNAL(triggered(bool)), this, SLOT(slotActionTriggered(bool)) );
 
-  mShowTextAction = new KAction( i18n( "Show Text Only" ), this );
+  mShowTextAction = new KAction( i18nc( "@action:inmenu", "Show Text Only" ), this );
   mShowTextAction->setCheckable( true );
   mShowTextAction->setActionGroup( viewMode );
   mShowTextAction->setChecked( mShowText && !mShowIcons );
+  mShowTextAction->setHelpText(
+    i18nc( "@info:status",
+           "Show sidebar items with text and without icons" ) );
+  mShowTextAction->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Choose this option if you want the sidebar items to have text without icons." ) );
   connect( mShowTextAction, SIGNAL(triggered(bool)), this, SLOT(slotActionTriggered(bool)) );
 
-  mShowBothAction = new KAction( i18n( "Show Icons && Text" ), this );
+  mShowBothAction = new KAction( i18nc( "@action:inmenu", "Show Icons && Text" ), this );
   mShowBothAction->setCheckable( true );
   mShowBothAction->setActionGroup( viewMode );
   mShowBothAction->setChecked( mShowText && mShowIcons );
+  mShowBothAction->setHelpText(
+    i18nc( "@info:status",
+           "Show sidebar items with icons and text" ) );
+  mShowBothAction->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Choose this option if you want the sidebar items to have icons and text." ) );
   connect( mShowBothAction, SIGNAL(triggered(bool)), this, SLOT(slotActionTriggered(bool)) );
 
   KAction *sep = new KAction( this );
@@ -265,22 +286,40 @@ Navigator::Navigator( SidePaneBase *parent )
 
   QActionGroup *iconSize = new QActionGroup( this );
 
-  mBigIconsAction = new KAction( i18n( "Big Icons" ), this );
+  mBigIconsAction = new KAction( i18nc( "@action:inmenu", "Big Icons" ), this );
   mBigIconsAction->setCheckable( iconSize );
   mBigIconsAction->setActionGroup( iconSize );
   mBigIconsAction->setChecked( mIconSize == KIconLoader::SizeLarge );
+  mBigIconsAction->setHelpText(
+    i18nc( "@info:status",
+           "Show large size sidebar icons" ) );
+  mBigIconsAction->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Choose this option if you want the sidebar icons to be extra big." ) );
   connect( mBigIconsAction, SIGNAL(triggered(bool)), this, SLOT(slotActionTriggered(bool)) );
 
-  mNormalIconsAction = new KAction( i18n( "Normal Icons" ), this );
+  mNormalIconsAction = new KAction( i18nc( "@action:inmenu", "Normal Icons" ), this );
   mNormalIconsAction->setCheckable( true );
   mNormalIconsAction->setActionGroup( iconSize );
   mNormalIconsAction->setChecked( mIconSize == KIconLoader::SizeMedium );
+  mNormalIconsAction->setHelpText(
+    i18nc( "@info:status",
+           "Show normal size sidebar icons" ) );
+  mNormalIconsAction->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Choose this option if you want the sidebar icons to be normal size." ) );
   connect( mNormalIconsAction, SIGNAL(triggered(bool)), this, SLOT(slotActionTriggered(bool)) );
 
-  mSmallIconsAction = new KAction( i18n( "Small Icons" ), this );
+  mSmallIconsAction = new KAction( i18nc( "@action:inmenu", "Small Icons" ), this );
   mSmallIconsAction->setCheckable( true );
   mSmallIconsAction->setActionGroup( iconSize );
   mSmallIconsAction->setChecked( mIconSize == KIconLoader::SizeSmallMedium );
+  mSmallIconsAction->setHelpText(
+    i18nc( "@info:status",
+           "Show small size sidebar icons" ) );
+  mSmallIconsAction->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Choose this option if you want the sidebar icons to be extra small." ) );
   connect( mSmallIconsAction, SIGNAL(triggered(bool)), this, SLOT(slotActionTriggered(bool)) );
 
   QList<QAction*> actionList;
@@ -306,15 +345,15 @@ Navigator::Navigator( SidePaneBase *parent )
            this, SLOT(slotCurrentChanged(QModelIndex)) );
 }
 
-void Navigator::updatePlugins( QList<Kontact::Plugin*> plugins_ )
+void Navigator::updatePlugins( QList<KontactInterface::Plugin*> plugins_ )
 {
   QString currentPlugin;
   if ( currentIndex().isValid() ) {
     currentPlugin = currentIndex().model()->data( currentIndex(), Model::PluginName ).toString();
   }
 
-  QList<Kontact::Plugin*> pluginsToShow;
-  foreach ( Kontact::Plugin *plugin, plugins_ ) {
+  QList<KontactInterface::Plugin*> pluginsToShow;
+  foreach ( KontactInterface::Plugin *plugin, plugins_ ) {
     if ( plugin->showInSideBar() ) {
       pluginsToShow << plugin;
     }
@@ -385,8 +424,8 @@ void Navigator::dragMoveEvent( QDragMoveEvent *event )
   } else {
     const QModelIndex sourceIndex =
       static_cast<const QSortFilterProxyModel*>( model() )->mapToSource( dropIndex );
-    Kontact::Plugin *plugin =
-      static_cast<Kontact::Plugin*>( sourceIndex.internalPointer() );
+    KontactInterface::Plugin *plugin =
+      static_cast<KontactInterface::Plugin*>( sourceIndex.internalPointer() );
     if ( !plugin->canDecodeMimeData( event->mimeData() ) ) {
       event->setAccepted( false );
       return;
@@ -409,8 +448,8 @@ void Navigator::dropEvent( QDropEvent *event )
   } else {
     const QModelIndex sourceIndex =
       static_cast<const QSortFilterProxyModel*>( model() )->mapToSource( dropIndex );
-    Kontact::Plugin *plugin =
-      static_cast<Kontact::Plugin*>( sourceIndex.internalPointer() );
+    KontactInterface::Plugin *plugin =
+      static_cast<KontactInterface::Plugin*>( sourceIndex.internalPointer() );
     plugin->processDropEvent( event );
   }
 }
@@ -433,7 +472,7 @@ void Navigator::slotCurrentChanged( const QModelIndex &current )
   QModelIndex source =
     static_cast<const QSortFilterProxyModel*>( current.model() )->mapToSource( current );
 
-  emit pluginActivated( static_cast<Kontact::Plugin*>( source.internalPointer() ) );
+  emit pluginActivated( static_cast<KontactInterface::Plugin*>( source.internalPointer() ) );
 }
 
 void Navigator::slotActionTriggered( bool checked )
@@ -461,7 +500,7 @@ void Navigator::slotActionTriggered( bool checked )
   Prefs::self()->setSidePaneShowIcons( mShowIcons );
   Prefs::self()->setSidePaneShowText( mShowText );
 
-  mModel->emitLayoutChanged();
+  mModel->emitReset();
 
   QTimer::singleShot( 0, this, SLOT(updateNavigatorSize()) );
 }
@@ -472,13 +511,13 @@ void Navigator::updateNavigatorSize()
   parentWidget()->setMinimumWidth( sizeHint().width() );
 }
 
-IconSidePane::IconSidePane( Core *core, QWidget *parent )
+IconSidePane::IconSidePane( KontactInterface::Core *core, QWidget *parent )
   : SidePaneBase( core, parent )
 {
   mNavigator = new Navigator( this );
   mNavigator->setFocusPolicy( Qt::NoFocus );
-  connect( mNavigator, SIGNAL(pluginActivated(Kontact::Plugin*)),
-           SIGNAL(pluginSelected(Kontact::Plugin*)) );
+  connect( mNavigator, SIGNAL(pluginActivated(KontactInterface::Plugin*)),
+           SIGNAL(pluginSelected(KontactInterface::Plugin*)) );
 }
 
 IconSidePane::~IconSidePane()
@@ -502,8 +541,6 @@ void IconSidePane::resizeEvent( QResizeEvent *event )
   setMinimumWidth( mNavigator->sizeHint().width() );
 }
 
-}
-
 #include "iconsidepane.moc"
 
 // vim: sw=2 sts=2 et tw=80
