@@ -118,18 +118,13 @@ ActionManager::ActionManager( KXMLGUIClient *client, CalendarView *widget,
                               QObject *parent, KOrg::MainWindow *mainWindow,
                               bool isPart, KMenuBar *menuBar )
   : QObject( parent ),
-    mCollectionViewShowAction( 0 ), mCalendarModel( 0 ), mCalendar( 0 ),
+    mCollectionViewShowAction( 0 ), mCalendar( 0 ),
     mCollectionView( 0 ), mCollectionViewStateSaver( 0 ),
     mCollectionSelectionModelStateSaver( 0 ), mIsClosing( false )
 {
   new KOrgCalendarAdaptor( this );
   QDBusConnection::sessionBus().registerObject( "/Calendar", this );
 
-  // Construct the groupware object, it'll take care of the IncidenceEditors::EditorConfig as well
-  if ( !IncidenceEditorNG::GroupwareIntegration::isActive() ) {
-    IncidenceEditorNG::GroupwareIntegration::activate();
-  }
-
   mGUIClient = client;
   mACollection = mGUIClient->actionCollection();
   mCalendarView = widget;
@@ -264,27 +259,32 @@ void ActionManager::createCalendarAkonadi()
   monitor->setMimeTypeMonitored( KCalCore::Event::eventMimeType(), true );
   monitor->setMimeTypeMonitored( KCalCore::Todo::todoMimeType(), true );
   monitor->setMimeTypeMonitored( KCalCore::Journal::journalMimeType(), true );
-  mCalendarModel = new CalendarSupport::CalendarModel( monitor, this );
-  //mCalendarModel->setItemPopulationStrategy( Akonadi::EntityTreeModel::LazyPopulation );
+  CalendarSupport::CalendarModel *calendarModel = new CalendarSupport::CalendarModel( monitor, this );
+  calendarModel->setObjectName( "KOrg CalendarModel" );
+  //calendarModel->setItemPopulationStrategy( Akonadi::EntityTreeModel::LazyPopulation );
 
   // Our calendar tree must be sorted.
   QSortFilterProxyModel *sortFilterProxy = new QSortFilterProxyModel( this );
+  sortFilterProxy->setObjectName( "Sort" );
   sortFilterProxy->setDynamicSortFilter( true );
   sortFilterProxy->setSortCaseSensitivity( Qt::CaseInsensitive );
-  sortFilterProxy->setSourceModel( mCalendarModel );
+  sortFilterProxy->setSourceModel( calendarModel );
 
   // We're only interested in the CollectionTitle column
   KColumnFilterProxyModel *columnFilterProxy = new KColumnFilterProxyModel( this );
   columnFilterProxy->setSourceModel( sortFilterProxy );
   columnFilterProxy->setVisibleColumn( CalendarSupport::CalendarModel::CollectionTitle );
+  columnFilterProxy->setObjectName( "Remove columns" );
 
   // Keep track of selected items.
   QItemSelectionModel* selectionModel = new QItemSelectionModel( columnFilterProxy );
+  selectionModel->setObjectName( "Calendar Selection Model" );
 
   // Make item selection work by means of checkboxes.
   KCheckableProxyModel *checkableProxy = new KCheckableProxyModel( this );
   checkableProxy->setSelectionModel( selectionModel );
   checkableProxy->setSourceModel( columnFilterProxy );
+  checkableProxy->setObjectName( "Add checkboxes" );
 
   KConfig *config = KOGlobals::self()->config();
   mCollectionSelectionModelStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>( config->group( "GlobalCollectionSelection" ) );
@@ -293,6 +293,7 @@ void ActionManager::createCalendarAkonadi()
   AkonadiCollectionViewFactory factory( mCalendarView );
   mCalendarView->addExtension( &factory );
   mCollectionView = factory.collectionView();
+  mCollectionView->setObjectName( "Resource View" );
   connect( mCollectionView, SIGNAL(resourcesChanged(bool)), SLOT(slotResourcesChanged(bool)));
   connect( mCollectionView, SIGNAL(resourcesAddedRemoved()), SLOT(slotResourcesAddedRemoved()));
   connect( mCollectionView, SIGNAL(defaultResourceChanged(Akonadi::Collection)),
@@ -308,20 +309,28 @@ void ActionManager::createCalendarAkonadi()
   CalendarSupport::CollectionSelection *colSel = new CalendarSupport::CollectionSelection( selectionModel );
   EventViews::EventView::setGlobalCollectionSelection( colSel );
   KSelectionProxyModel* selectionProxy = new KSelectionProxyModel( selectionModel );
+  selectionProxy->setObjectName( "Only show items of selected collection" );
   selectionProxy->setFilterBehavior( KSelectionProxyModel::ChildrenOfExactSelection );
-  selectionProxy->setSourceModel( mCalendarModel );
+  selectionProxy->setSourceModel( calendarModel );
 
   Akonadi::EntityMimeTypeFilterModel* filterProxy2 = new Akonadi::EntityMimeTypeFilterModel( this );
 
   filterProxy2->setHeaderGroup( Akonadi::EntityTreeModel::ItemListHeaders );
   filterProxy2->setSourceModel( selectionProxy );
   filterProxy2->setSortRole( CalendarSupport::CalendarModel::SortRole );
+  filterProxy2->setObjectName( "Show headers" );
 
-  mCalendar = new CalendarSupport::Calendar( mCalendarModel, filterProxy2, KSystemTimeZones::local() );
+  mCalendar = new CalendarSupport::Calendar( calendarModel, filterProxy2, KSystemTimeZones::local() );
+  mCalendar->setObjectName( "KOrg Calendar" );
 
   mCalendarView->setCalendar( mCalendar );
   mCalendarView->readSettings();
 
+  // Construct the groupware object, it'll take care of the IncidenceEditors::EditorConfig as well
+  if ( !IncidenceEditorNG::GroupwareIntegration::isActive() ) {
+    IncidenceEditorNG::GroupwareIntegration::activate( mCalendar );
+  }
+
   connect( mCalendar, SIGNAL(calendarChanged()),
            mCalendarView, SLOT(resourcesChanged()) );
   connect( mCalendar, SIGNAL(signalErrorMessage(const QString &)),
@@ -367,7 +376,7 @@ void ActionManager::initActions()
     i18n( "Select this menu entry if you would like to merge the contents "
           "of another iCalendar into your current calendar." ) );
   mACollection->addAction( "import_icalendar", mergeAction );
-  connect( mergeAction, SIGNAL(triggered(bool)), SLOT(file_merge()) );
+  connect( mergeAction, SIGNAL(triggered(bool)), SLOT(file_import()) );
 
   KAction *importAction = new KAction( i18n( "&Import From UNIX Ical Tool" ), this );
   importAction->setHelpText(
@@ -900,16 +909,17 @@ void ActionManager::writeSettings()
   config.sync();
 }
 
+/*
 void ActionManager::file_new()
 {
-  emit actionNew();
+  emit actionNewMainWindow();
 }
+*/
 
 void ActionManager::file_open()
 {
-  KUrl url;
   const QString defaultPath = KStandardDirs::locateLocal( "data","korganizer/" );
-  url = KFileDialog::getOpenUrl( defaultPath, "text/calendar", dialogParent() );
+  const KUrl url = KFileDialog::getOpenUrl( defaultPath, "text/calendar", dialogParent() );
 
   file_open( url );
 }
@@ -931,7 +941,7 @@ void ActionManager::file_open( const KUrl &url )
 
   kDebug() << url.prettyUrl();
 
-  emit actionNew( url );
+  importCalendar( url );
 }
 
 void ActionManager::file_icalimport()
@@ -991,7 +1001,7 @@ void ActionManager::file_icalimport()
   }
 }
 
-void ActionManager::file_merge()
+void ActionManager::file_import()
 {
   const KUrl url = KFileDialog::getOpenUrl( KStandardDirs::locateLocal( "data","korganizer/" ),
                                       "text/calendar",
@@ -1499,19 +1509,19 @@ QString ActionManager::getCurrentURLasString() const
   return mURL.url();
 }
 
-bool ActionManager::editIncidence( const Akonadi::Item::Id &uid )
+bool ActionManager::editIncidence( Akonadi::Item::Id id )
 {
-  return mCalendarView->editIncidence( uid );
+  return mCalendarView->editIncidence( id );
 }
 
-bool ActionManager::showIncidence( const Akonadi::Item::Id &uid )
+bool ActionManager::showIncidence( Akonadi::Item::Id id )
 {
-  return mCalendarView->showIncidence( uid );
+  return mCalendarView->showIncidence( id );
 }
 
-bool ActionManager::showIncidenceContext( const Akonadi::Item::Id &uid )
+bool ActionManager::showIncidenceContext( Akonadi::Item::Id id )
 {
-  return mCalendarView->showIncidenceContext( uid );
+  return mCalendarView->showIncidenceContext( id );
 }
 
 bool ActionManager::handleCommandLine()
@@ -1549,9 +1559,9 @@ bool ActionManager::handleCommandLine()
   return ret;
 }
 
-bool ActionManager::deleteIncidence( const Akonadi::Item::Id &uid, bool force )
+bool ActionManager::deleteIncidence( Akonadi::Item::Id id, bool force )
 {
-  return mCalendarView->deleteIncidence( uid, force );
+  return mCalendarView->deleteIncidence( id, force );
 }
 
 bool ActionManager::addIncidence( const QString &ical )
