@@ -170,10 +170,10 @@ class KDEPIM_EXPORT KCheckComboBox : public KComboBox
     class Private;
     Private *const d;
 
-    Q_PRIVATE_SLOT( d, void makeInsertedItemsCheckable(const QModelIndex &, int start, int end) );
+    Q_PRIVATE_SLOT( d, void makeInsertedItemsCheckable(const QModelIndex &, int start, int end) )
     Q_PRIVATE_SLOT( d, void updateCheckedItems( const QModelIndex &topLeft,
-                                                const QModelIndex &bottomRight ) );
-    Q_PRIVATE_SLOT( d, void toggleCheckState() );
+                                                const QModelIndex &bottomRight ) )
+    Q_PRIVATE_SLOT( d, void toggleCheckState() )
     //@endcond
 };
 
