@@ -541,17 +541,43 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor( const KMime::Mess
       result = result.arg( tempFileName );
   }
 
-  // And finally, replace the %{foo} with the content of the foo
-  // header field:
+  return result;
+}
+
+namespace {
+
+/**
+ * Substitutes placeholders in the command line with the
+ * content of the correspoding header in the message.
+ * %{From} -> Joe Author <joe@acme.com>
+ */
+void substituteMessageHeaders( const KMime::Message::Ptr &aMsg, QString &result )
+{
+  // Replace the %{foo} with the content of the foo header field.
+  // If the header doesn't exist, remove the placeholder.
   QRegExp header_rx( "%\\{([a-z0-9-]+)\\}", Qt::CaseInsensitive );
   int idx = 0;
   while ( ( idx = header_rx.indexIn( result, idx ) ) != -1 ) {
-    QString replacement = KShell::quoteArg( aMsg->headerByType( header_rx.cap(1).toLatin1() ) ? aMsg->headerByType( header_rx.cap(1).toLatin1() )->as7BitString() : "" );
+    const KMime::Headers::Base* header = aMsg->headerByType( header_rx.cap(1).toLatin1() );
+    QString replacement;
+    if ( header )
+      replacement = KShell::quoteArg( header->as7BitString() );
     result.replace( idx, header_rx.matchedLength(), replacement );
     idx += replacement.length();
   }
+}
+
+/**
+ * Substitutes placeholders in the command line with the
+ * corresponding information from the item. Currently supported
+ * are %{itemid} and %{itemurl}.
+ */
+void substituteCommandLineArgsForItem( const Akonadi::Item &item, QString &commandLine )
+{
+  commandLine.replace( QLatin1String( "%{itemurl}" ), item.url( Akonadi::Item::UrlWithMimeType ).url() );
+  commandLine.replace( QLatin1String( "%{itemid}" ), QString::number( item.id() ) );
+}
 
-  return result;
 }
 
 FilterAction::ReturnCode FilterActionWithCommand::genericProcess( const Akonadi::Item &item, bool withOutput ) const
@@ -572,6 +598,9 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess( const Akonadi:
   atmList.append( inFile );
 
   QString commandLine = substituteCommandLineArgsFor( aMsg, atmList );
+  substituteCommandLineArgsForItem( item, commandLine );
+  substituteMessageHeaders( aMsg, commandLine );
+
   if ( commandLine.isEmpty() ) {
     qDeleteAll( atmList );
     atmList.clear();
@@ -924,6 +953,16 @@ bool FilterActionSetStatus::requiresBody() const
   return false;
 }
 
+static QString realStatusString( const QString &statusStr )
+{
+  QString result( statusStr );
+
+  if ( result.size() == 2 )
+    result.remove( QLatin1Char( 'U' ) );
+
+  return result;
+}
+
 void FilterActionSetStatus::argsFromString( const QString &argsStr )
 {
   if ( argsStr.length() == 1 ) {
@@ -931,7 +970,7 @@ void FilterActionSetStatus::argsFromString( const QString &argsStr )
 
     for ( int i = 0 ; i < StatiCount ; ++i ) {
       status = stati[i];
-      if ( status.statusStr()[0] == argsStr[0].toLatin1() ) {
+      if ( realStatusString( status.statusStr() ) == argsStr.toLatin1() ) {
         mParameter = mParameterList.at( i + 1 );
         return;
       }
@@ -947,7 +986,7 @@ QString FilterActionSetStatus::argsAsString() const
   if ( index < 1 )
     return QString();
 
-  return stati[index - 1].statusStr();
+  return realStatusString( stati[index - 1].statusStr() );
 }
 
 QString FilterActionSetStatus::displayString() const
@@ -1186,7 +1225,7 @@ QWidget* FilterActionRemoveHeader::createParamWidget( QWidget *parent ) const
   comboBox->setEditable( true );
   comboBox->setInsertPolicy( QComboBox::InsertAtBottom );
   setParamWidgetValue( comboBox );
-  
+
   connect( comboBox, SIGNAL( currentIndexChanged( int ) ),
            this, SIGNAL( filterActionModified() ) );
 
@@ -1312,7 +1351,7 @@ QWidget* FilterActionAddHeader::createParamWidget( QWidget *parent ) const
   layout->addWidget( lineEdit, 1 );
 
   setParamWidgetValue( widget );
-  
+
   connect( comboBox, SIGNAL( currentIndexChanged( int ) ),
            this, SIGNAL( filterActionModified() ) );
   connect( lineEdit, SIGNAL( textChanged( QString ) ),
@@ -2427,4 +2466,5 @@ const QList<FilterActionDesc*>& FilterActionDict::list() const
   return mList;
 }
 
+
 #include "filteraction.moc"
