@@ -28,13 +28,14 @@
 #include "core/model.h"
 #include "core/model_p.h"
 #include "core/settings.h"
-#include "core/configprovider.h"
 
 #include "utils/configureaggregationsdialog.h"
 #include "utils/configureaggregationsdialog_p.h"
 #include "utils/configurethemesdialog.h"
 #include "utils/configurethemesdialog_p.h"
 
+#include "messagecore/globalsettings.h"
+
 #include <QPixmap>
 
 #include <kmime/kmime_dateformatter.h> // kdepimlibs
@@ -45,6 +46,7 @@
 #include <KGlobalSettings>
 #include <KApplication>
 #include <KLocale>
+#include <KStandardDirs>
 
 using namespace MessageList::Core;
 
@@ -57,8 +59,6 @@ Manager::Manager()
 
   mDateFormatter = new KMime::DateFormatter();
 
-  mDisplayMessageToolTips = true;
-
   mPixmapMessageNew = new QPixmap( SmallIcon( QLatin1String( "mail-unread-new" ) ) );
   mPixmapMessageUnread = new QPixmap( SmallIcon( QLatin1String( "mail-unread" ) ) );
   mPixmapMessageRead = new QPixmap( SmallIcon( QLatin1String( "mail-read" ) ) );
@@ -70,8 +70,8 @@ Manager::Manager()
   mPixmapMessageSent = new QPixmap( SmallIcon( QLatin1String( "mail-sent" ) ) );
   mPixmapMessageForwarded = new QPixmap( SmallIcon( QLatin1String( "mail-forwarded" ) ) );
   mPixmapMessageImportant = new QPixmap( SmallIcon( QLatin1String( "emblem-important" ) ) ); // "flag"
-  mPixmapMessageWatched = new QPixmap( SmallIcon( QLatin1String( "mail-thread-watch" ) ) );
-  mPixmapMessageIgnored = new QPixmap( SmallIcon( QLatin1String( "mail-thread-ignored" ) ) );
+  mPixmapMessageWatched = new QPixmap( KStandardDirs::locate( "data", QLatin1String( "messagelist/pics/mail-thread-watch.png" ) ) );
+  mPixmapMessageIgnored = new QPixmap( KStandardDirs::locate( "data", QLatin1String( "messagelist/pics/mail-thread-ignored.png" ) ) );
   mPixmapMessageSpam = new QPixmap( SmallIcon( QLatin1String( "mail-mark-junk" ) ) );
   mPixmapMessageHam = new QPixmap( SmallIcon( QLatin1String( "mail-mark-notjunk" ) ) );
   mPixmapMessageFullySigned = new QPixmap( SmallIcon( QLatin1String( "mail-signed-verified" ) ) );
@@ -83,6 +83,8 @@ Manager::Manager()
   mPixmapMessageUndefinedEncrypted = new QPixmap( SmallIcon( QLatin1String( "mail-encrypted" ) ) );
   mPixmapMessageNotEncrypted = new QPixmap( SmallIcon( QLatin1String( "text-plain" ) ) );
   mPixmapMessageAttachment = new QPixmap( SmallIcon( QLatin1String( "mail-attachment" ) ) );
+  mPixmapMessageAnnotation = new QPixmap( SmallIcon( QLatin1String( "view-pim-notes" ) ) );
+  mPixmapMessageInvitation = new QPixmap( SmallIcon( QLatin1String( "mail-invitation" ) ) );
   //mPixmapShowMore = new QPixmap( SmallIcon( "list-add.png" ) );
   //mPixmapShowLess = new QPixmap( SmallIcon( "list-remove.png" ) );
   if ( KApplication::isRightToLeft() )
@@ -90,8 +92,8 @@ Manager::Manager()
   else
     mPixmapShowMore = new QPixmap( SmallIcon( QLatin1String( "arrow-right" ) ) );
   mPixmapShowLess = new QPixmap( SmallIcon( QLatin1String( "arrow-down" ) ) );
-  mPixmapVerticalLine = new QPixmap( SmallIcon( QLatin1String( "mail-vertical-separator-line" ) ) );
-  mPixmapHorizontalSpacer = new QPixmap( SmallIcon( QLatin1String( "mail-horizontal-space" ) ) );
+  mPixmapVerticalLine = new QPixmap( KStandardDirs::locate( "data", QLatin1String( "messagelist/pics/mail-vertical-separator-line.png" ) ) );
+  mPixmapHorizontalSpacer = new QPixmap( KStandardDirs::locate( "data", QLatin1String( "messagelist/pics/mail-horizontal-space.png" ) ) );
 
   mCachedLocalizedUnknownText = i18nc( "Unknown date", "Unknown" ) ;
 
@@ -130,6 +132,8 @@ Manager::~Manager()
   delete mPixmapMessageUndefinedEncrypted;
   delete mPixmapMessageNotEncrypted;
   delete mPixmapMessageAttachment;
+  delete mPixmapMessageAnnotation;
+  delete mPixmapMessageInvitation;
   delete mPixmapShowMore;
   delete mPixmapShowLess;
   delete mPixmapVerticalLine;
@@ -167,7 +171,7 @@ void Manager::unregisterWidget( Widget *pWidget )
 
 unsigned long Manager::preSelectedMessageForStorageModel( const StorageModel *storageModel )
 {
-  KConfigGroup conf( ConfigProvider::self()->config(),
+  KConfigGroup conf( Settings::self()->config(),
                      "MessageListView::StorageModelSelectedMessages" );
 
   // QVariant supports unsigned int OR unsigned long long int, NOT unsigned long int... doh...
@@ -178,7 +182,7 @@ unsigned long Manager::preSelectedMessageForStorageModel( const StorageModel *st
 
 void Manager::savePreSelectedMessageForStorageModel( const StorageModel * storageModel, unsigned long uniqueIdOfMessage )
 {
-  KConfigGroup conf( ConfigProvider::self()->config(),
+  KConfigGroup conf( Settings::self()->config(),
                      "MessageListView::StorageModelSelectedMessages" );
 
 
@@ -203,7 +207,7 @@ const Aggregation * Manager::aggregation( const QString &id )
 
 const Aggregation * Manager::defaultAggregation()
 {
-  KConfigGroup conf( ConfigProvider::self()->config(),
+  KConfigGroup conf( Settings::self()->config(),
                      "MessageListView::StorageModelAggregations" );
 
   QString aggregationId = conf.readEntry( QLatin1String( "DefaultSet" ), "" );
@@ -228,20 +232,43 @@ const Aggregation * Manager::defaultAggregation()
   return *it;
 }
 
+void Manager::saveAggregationForStorageModel( const Akonadi::Collection &col, const QString &id, bool storageUsesPrivateAggregation )
+{
+  if ( !col.isValid() )
+    return;
+  saveAggregationForStorageModel( QString::number( col.id() ), id, storageUsesPrivateAggregation );
+}
+
 void Manager::saveAggregationForStorageModel( const StorageModel *storageModel, const QString &id, bool storageUsesPrivateAggregation )
 {
-  KConfigGroup conf( ConfigProvider::self()->config(),
+  saveAggregationForStorageModel( storageModel->id(), id, storageUsesPrivateAggregation );
+}
+
+void Manager::saveAggregationForStorageModel( const QString &modelId, const QString &id, bool storageUsesPrivateAggregation )
+{
+  KConfigGroup conf( Settings::self()->config(),
                      "MessageListView::StorageModelAggregations" );
 
   if ( storageUsesPrivateAggregation )
-    conf.writeEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModel->id() ), id );
+    conf.writeEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( modelId ), id );
   else
-    conf.deleteEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModel->id() ) );
+    conf.deleteEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( modelId ) );
 
   if ( !storageUsesPrivateAggregation )
     conf.writeEntry( QLatin1String( "DefaultSet" ), id );
 }
 
+const Aggregation * Manager::aggregationForStorageModel( const Akonadi::Collection &col, bool *storageUsesPrivateAggregation )
+{
+  Q_ASSERT( storageUsesPrivateAggregation );
+
+  *storageUsesPrivateAggregation = false; // this is by default
+
+  if ( !col.isValid() )
+    return defaultAggregation();
+  return Manager::aggregationForStorageModel( QString::number( col.id() ), storageUsesPrivateAggregation );
+}
+
 
 const Aggregation * Manager::aggregationForStorageModel( const StorageModel *storageModel, bool *storageUsesPrivateAggregation )
 {
@@ -251,11 +278,15 @@ const Aggregation * Manager::aggregationForStorageModel( const StorageModel *sto
 
   if ( !storageModel )
     return defaultAggregation();
+  return Manager::aggregationForStorageModel( storageModel->id(), storageUsesPrivateAggregation );
+}
 
-  KConfigGroup conf( ConfigProvider::self()->config(),
+const Aggregation * Manager::aggregationForStorageModel( const QString &storageId, bool *storageUsesPrivateAggregation )
+{
+  KConfigGroup conf( Settings::self()->config(),
                      "MessageListView::StorageModelAggregations" );
 
-  QString aggregationId = conf.readEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModel->id() ), "" );
+  QString aggregationId = conf.readEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageId ), "" );
 
   Aggregation * opt = 0;
 
@@ -454,7 +485,7 @@ const SortOrder Manager::sortOrderForStorageModel( const StorageModel *storageMo
   if ( !storageModel )
     return SortOrder();
 
-  KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::StorageModelSortOrder" );
+  KConfigGroup conf( Settings::self()->config(), "MessageListView::StorageModelSortOrder" );
   SortOrder ret;
   ret.readConfig( conf, storageModel->id(), storageUsesPrivateSortOrder );
   return ret;
@@ -463,7 +494,7 @@ const SortOrder Manager::sortOrderForStorageModel( const StorageModel *storageMo
 void Manager::saveSortOrderForStorageModel( const StorageModel *storageModel,
                                             const SortOrder& order, bool storageUsesPrivateSortOrder )
 {
-  KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::StorageModelSortOrder" );
+  KConfigGroup conf( Settings::self()->config(), "MessageListView::StorageModelSortOrder" );
   order.writeConfig( conf, storageModel->id(), storageUsesPrivateSortOrder );
 }
 
@@ -478,7 +509,7 @@ const Theme * Manager::theme( const QString &id )
 
 const Theme * Manager::defaultTheme()
 {
-  KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::StorageModelThemes" );
+  KConfigGroup conf( Settings::self()->config(), "MessageListView::StorageModelThemes" );
 
   QString themeId = conf.readEntry( QLatin1String( "DefaultSet" ), "" );
 
@@ -505,31 +536,59 @@ const Theme * Manager::defaultTheme()
   return *it;
 }
 
+void Manager::saveThemeForStorageModel( int index, const QString &id, bool storageUsesPrivateTheme )
+{
+  saveThemeForStorageModel( QString::number( index ), id, storageUsesPrivateTheme );
+}
+
 void Manager::saveThemeForStorageModel( const StorageModel *storageModel, const QString &id, bool storageUsesPrivateTheme )
 {
-  KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::StorageModelThemes" );
+  saveThemeForStorageModel( storageModel->id(), id, storageUsesPrivateTheme );
+}
+
+void Manager::saveThemeForStorageModel( const QString &storageModelIndex, const QString &id, bool storageUsesPrivateTheme )
+{
+  KConfigGroup conf( Settings::self()->config(), "MessageListView::StorageModelThemes" );
 
   if ( storageUsesPrivateTheme )
-    conf.writeEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModel->id() ), id );
+    conf.writeEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModelIndex ), id );
   else
-    conf.deleteEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModel->id() ) );
+    conf.deleteEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModelIndex ) );
 
   if ( !storageUsesPrivateTheme )
     conf.writeEntry( QLatin1String( "DefaultSet" ), id );
 }
 
 
+const Theme * Manager::themeForStorageModel( const Akonadi::Collection & col,  bool * storageUsesPrivateTheme )
+{
+  Q_ASSERT( storageUsesPrivateTheme );
+
+  *storageUsesPrivateTheme = false; // this is by default
+
+  if ( !col.isValid() )
+    return defaultTheme();
+  return Manager::themeForStorageModel( QString::number( col.id() ), storageUsesPrivateTheme );
+
+}
+
 const Theme * Manager::themeForStorageModel( const StorageModel *storageModel, bool *storageUsesPrivateTheme )
 {
+
+
   Q_ASSERT( storageUsesPrivateTheme );
 
   *storageUsesPrivateTheme = false; // this is by default
 
   if ( !storageModel )
     return defaultTheme();
+  return Manager::themeForStorageModel( storageModel->id(), storageUsesPrivateTheme );
+}
 
-  KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::StorageModelThemes" );
-  QString themeId = conf.readEntry( QString( QLatin1String( "SetForStorageModel%1" ) ).arg( storageModel->id() ), "" );
+const Theme * Manager::themeForStorageModel( const QString &id, bool *storageUsesPrivateTheme )
+{
+  KConfigGroup conf( Settings::self()->config(), "MessageListView::StorageModelThemes" );
+  QString themeId = conf.readEntry( QString(QLatin1String(  "SetForStorageModel%1" )).arg( id ), "" );
 
   Theme * opt = 0;
 
@@ -655,6 +714,12 @@ void Manager::createDefaultThemes()
       r->addLeftItem( i );
         i = new Theme::ContentItem( Theme::ContentItem::AttachmentStateIcon );
         i->setHideWhenDisabled( true );
+      r->addLeftItem( i );
+        i = new Theme::ContentItem( Theme::ContentItem::AnnotationIcon );
+        i->setHideWhenDisabled( true );
+      r->addLeftItem( i );
+        i = new Theme::ContentItem( Theme::ContentItem::InvitationIcon );
+        i->setHideWhenDisabled( true );
       r->addLeftItem( i );
         i = new Theme::ContentItem( Theme::ContentItem::SignatureStateIcon );
         i->setHideWhenDisabled( true );
@@ -676,7 +741,7 @@ void Manager::createDefaultThemes()
   add_theme_simple_text_column( s, i18n( "Most Recent Date" ), Theme::ContentItem::MostRecentDate, false, SortOrder::SortMessagesByDateTimeOfMostRecent, false, true );
   add_theme_simple_text_column( s, i18nc( "Size of a message", "Size" ), Theme::ContentItem::Size, false, SortOrder::SortMessagesBySize, false, false );
   add_theme_simple_icon_column( s, i18nc( "Attachement indication", "Attachment" ), QLatin1String( "mail-attachment" ), Theme::ContentItem::AttachmentStateIcon, false, SortOrder::NoMessageSorting );
-  add_theme_simple_icon_column( s, i18n( "New/Unread" ), QLatin1String( "mail-unread-new" ), Theme::ContentItem::ReadStateIcon, false, SortOrder::SortMessagesByNewUnreadStatus );
+  add_theme_simple_icon_column( s, i18n( "Unread" ), QLatin1String( "mail-unread-new" ), Theme::ContentItem::ReadStateIcon, false, SortOrder::SortMessagesByUnreadStatus );
   add_theme_simple_icon_column( s, i18n( "Replied" ), QLatin1String( "mail-replied" ), Theme::ContentItem::RepliedStateIcon, false, SortOrder::NoMessageSorting );
   add_theme_simple_icon_column( s, i18nc( "Message importance indication", "Important" ), QLatin1String( "emblem-important" ), Theme::ContentItem::ImportantStateIcon, false, SortOrder::NoMessageSorting );
   add_theme_simple_icon_column( s, i18n( "Action Item" ), QLatin1String( "mail-task" ), Theme::ContentItem::ActionItemStateIcon, false, SortOrder::SortMessagesByActionItemStatus );
@@ -721,6 +786,12 @@ void Manager::createDefaultThemes()
       r->addRightItem( i );
         i = new Theme::ContentItem( Theme::ContentItem::AttachmentStateIcon );
         i->setHideWhenDisabled( true );
+      r->addRightItem( i );
+        i = new Theme::ContentItem( Theme::ContentItem::AnnotationIcon );
+        i->setHideWhenDisabled( true );
+      r->addRightItem( i );
+        i = new Theme::ContentItem( Theme::ContentItem::InvitationIcon );
+        i->setHideWhenDisabled( true );
       r->addRightItem( i );
         i = new Theme::ContentItem( Theme::ContentItem::EncryptionStateIcon );
         i->setHideWhenDisabled( true );
@@ -865,16 +936,10 @@ void Manager::reloadGlobalConfiguration()
 void Manager::loadGlobalConfiguration()
 {
   // Load the date format
-  KConfigGroup config( ConfigProvider::self()->config(), "General" );
-
-  KMime::DateFormatter::FormatType t = (KMime::DateFormatter::FormatType) config.readEntry(
-      "dateFormat",
-      ( int )KMime::DateFormatter::Fancy
-    );
-  mDateFormatter->setCustomFormat( config.readEntry( "customDateFormat", QString() ) );
-  mDateFormatter->setFormat( t );
-
-  mDisplayMessageToolTips = Settings::self()->messageToolTipEnabled();
+  const KMime::DateFormatter::FormatType type = static_cast<KMime::DateFormatter::FormatType>(
+       MessageCore::GlobalSettings::self()->dateFormat() );
+  mDateFormatter->setCustomFormat( MessageCore::GlobalSettings::self()->customDateFormat() );
+  mDateFormatter->setFormat( type );
 }
 
 void Manager::loadConfiguration()
@@ -884,7 +949,7 @@ void Manager::loadConfiguration()
   {
     // load Aggregations
 
-    KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::Aggregations" );
+    KConfigGroup conf( Settings::self()->config(), "MessageListView::Aggregations" );
 
     mAggregations.clear();
 
@@ -919,7 +984,7 @@ void Manager::loadConfiguration()
   {
     // load Themes
 
-    KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::Themes" );
+    KConfigGroup conf( Settings::self()->config(), "MessageListView::Themes" );
 
     mThemes.clear();
 
@@ -956,7 +1021,6 @@ void Manager::loadConfiguration()
 
 void Manager::saveGlobalConfiguration()
 {
-  Settings::self()->setMessageToolTipEnabled( mDisplayMessageToolTips );
   Settings::self()->writeConfig();
 }
 
@@ -967,7 +1031,7 @@ void Manager::saveConfiguration()
   {
     // store aggregations
 
-    KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::Aggregations" );
+    KConfigGroup conf( Settings::self()->config(), "MessageListView::Aggregations" );
     //conf.clear();
 
     conf.writeEntry( "Count", mAggregations.count() );
@@ -983,7 +1047,7 @@ void Manager::saveConfiguration()
   {
     // store themes
 
-    KConfigGroup conf( ConfigProvider::self()->config(), "MessageListView::Themes" );
+    KConfigGroup conf( Settings::self()->config(), "MessageListView::Themes" );
     //conf.clear();
 
     conf.writeEntry( "Count", mThemes.count() );
@@ -996,6 +1060,6 @@ void Manager::saveConfiguration()
     }
   }
 
-  ConfigProvider::self()->config()->sync();
+  Settings::self()->config()->sync();
 }
 
