@@ -27,32 +27,29 @@
 #include <kglobal.h>
 #include <klocale.h>
 
-static const KCmdLineOptions options[] =
-{
-  {"verbose", "Verbose output", 0},
-  KCmdLineLastOption
-};
-
 int main(int argc,char **argv)
 {
-  KLocale::setMainCatalogue( "kdepimwizards" ); 
+  KLocale::setMainCatalog( "kdepimwizards" ); 
 
-  KAboutData aboutData( "groupwisewizard",
-                        I18N_NOOP( "Novell GroupWise Configuration Wizard" ),
+  KAboutData aboutData( "groupwisewizard", 0,
+                        ki18n( "Novell GroupWise Configuration Wizard" ),
                         "0.1" );
   KCmdLineArgs::init( argc, argv, &aboutData );
+
+  KCmdLineOptions options;
+  options.add("verbose", ki18n("Verbose output"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KApplication app;
 
-  KGlobal::locale()->insertCatalogue( "libkdepim" );
+  KGlobal::locale()->insertCatalog( "libkdepim" );
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
   bool verbose = false;
   if ( args->isSet( "verbose" ) ) verbose = true;
-
+  args->clear();
   GroupwiseWizard wizard;
 
-  wizard.exec();
+  return wizard.exec();
 }
